@@ -10,9 +10,8 @@
 #undef HAVE_SOCKET
 #undef HAVE_STRUCT_LINGER
 #undef HAVE_NSL
-#undef USING_OAF
-#undef HAVE_GCONF
 #undef HAVE_OLDER_BZIP2
 #undef GNOME_PLATFORM_VERSION
 #undef ENABLE_PROFILER
 #undef HAVE_OPENSSL
+#undef HAVE_FAM
