@@ -21,137 +21,16 @@
 
    Author: Ettore Perazzoli <ettore@comm2000.it> */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
-#include "gnome-vfs.h"
-#include "gnome-vfs-private.h"
-
-#include "gnome-vfs-job.h"
 #include "gnome-vfs-async-job-map.h"
-
+#include "gnome-vfs-job.h"
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
 #include <unistd.h>
 
-void           pthread_gnome_vfs_async_cancel                 (GnomeVFSAsyncHandle                 *handle);
-void           pthread_gnome_vfs_async_open_uri               (GnomeVFSAsyncHandle                **handle_return,
-							       GnomeVFSURI                         *uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       GnomeVFSAsyncOpenCallback            callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_open                   (GnomeVFSAsyncHandle                **handle_return,
-							       const gchar                         *text_uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       GnomeVFSAsyncOpenCallback            callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_open_uri_as_channel    (GnomeVFSAsyncHandle                **handle_return,
-							       GnomeVFSURI                         *uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       guint                                advised_block_size,
-							       GnomeVFSAsyncOpenAsChannelCallback   callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_open_as_channel        (GnomeVFSAsyncHandle                **handle_return,
-							       const gchar                         *text_uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       guint                                advised_block_size,
-							       GnomeVFSAsyncOpenAsChannelCallback   callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_create_uri             (GnomeVFSAsyncHandle                **handle_return,
-							       GnomeVFSURI                         *uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       gboolean                             exclusive,
-							       guint                                perm,
-							       GnomeVFSAsyncOpenCallback            callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_create_symbolic_link   (GnomeVFSAsyncHandle                **handle_return,
-							       GnomeVFSURI                         *uri,
-							       const gchar                         *uri_reference,
-							       GnomeVFSAsyncOpenCallback            callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_create                 (GnomeVFSAsyncHandle                **handle_return,
-							       const gchar                         *text_uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       gboolean                             exclusive,
-							       guint                                perm,
-							       GnomeVFSAsyncOpenCallback            callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_create_as_channel      (GnomeVFSAsyncHandle                **handle_return,
-							       const gchar                         *text_uri,
-							       GnomeVFSOpenMode                     open_mode,
-							       gboolean                             exclusive,
-							       guint                                perm,
-							       GnomeVFSAsyncOpenAsChannelCallback   callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_close                  (GnomeVFSAsyncHandle                 *handle,
-							       GnomeVFSAsyncCloseCallback           callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_read                   (GnomeVFSAsyncHandle                 *handle,
-							       gpointer                             buffer,
-							       guint                                bytes,
-							       GnomeVFSAsyncReadCallback            callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_write                  (GnomeVFSAsyncHandle                 *handle,
-							       gconstpointer                        buffer,
-							       guint                                bytes,
-							       GnomeVFSAsyncWriteCallback           callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_get_file_info          (GnomeVFSAsyncHandle                **handle_return,
-							       GList                               *uris,
-							       GnomeVFSFileInfoOptions              options,
-							       GnomeVFSAsyncGetFileInfoCallback     callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_set_file_info          (GnomeVFSAsyncHandle                **handle_return,
-							       GnomeVFSURI                         *uri,
-							       GnomeVFSFileInfo                    *info,
-							       GnomeVFSSetFileInfoMask              mask,
-							       GnomeVFSFileInfoOptions              options,
-							       GnomeVFSAsyncSetFileInfoCallback     callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_load_directory         (GnomeVFSAsyncHandle                **handle_return,
-							       const gchar                         *text_uri,
-							       GnomeVFSFileInfoOptions              options,
-							       GnomeVFSDirectoryFilterType          filter_type,
-							       GnomeVFSDirectoryFilterOptions       filter_options,
-							       const gchar                         *filter_pattern,
-							       guint                                items_per_notification,
-							       GnomeVFSAsyncDirectoryLoadCallback   callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_load_directory_uri     (GnomeVFSAsyncHandle                **handle_return,
-							       GnomeVFSURI                         *uri,
-							       GnomeVFSFileInfoOptions              options,
-							       GnomeVFSDirectoryFilterType          filter_type,
-							       GnomeVFSDirectoryFilterOptions       filter_options,
-							       const gchar                         *filter_pattern,
-							       guint                                items_per_notification,
-							       GnomeVFSAsyncDirectoryLoadCallback   callback,
-							       gpointer                             callback_data);
-void           pthread_gnome_vfs_async_find_directory         (GnomeVFSAsyncHandle                **handle_return,
-							       GList                               *uris,
-							       GnomeVFSFindDirectoryKind            kind,
-							       gboolean                             create_if_needed,
-							       gboolean                             find_if_needed,
-							       guint                                permissions,
-							       GnomeVFSAsyncFindDirectoryCallback   callback,
-							       gpointer                             user_data);
-GnomeVFSResult pthread_gnome_vfs_async_xfer                   (GnomeVFSAsyncHandle                **handle_return,
-							       GList                               *source_uri_list,
-							       GList                               *target_uri_list,
-							       GnomeVFSXferOptions                  xfer_options,
-							       GnomeVFSXferErrorMode                error_mode,
-							       GnomeVFSXferOverwriteMode            overwrite_mode,
-							       GnomeVFSAsyncXferProgressCallback    progress_update_callback,
-							       gpointer                             update_callback_data,
-							       GnomeVFSXferProgressCallback         progress_sync_callback,
-							       gpointer                             sync_callback_data);
-guint          pthread_gnome_vfs_async_add_status_callback    (GnomeVFSAsyncHandle                 *handle,
-							       GnomeVFSStatusCallback               callback,
-							       gpointer                             user_data);
-void           pthread_gnome_vfs_async_remove_status_callback (GnomeVFSAsyncHandle                 *handle,
-							       guint                                callback_id);
-
-
 void
-pthread_gnome_vfs_async_cancel (GnomeVFSAsyncHandle *handle)
+gnome_vfs_async_cancel (GnomeVFSAsyncHandle *handle)
 {
 	GnomeVFSJob *job;
 	
@@ -197,7 +76,7 @@ async_open (GnomeVFSURI *uri,
 }
 
 void
-pthread_gnome_vfs_async_open_uri (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_open_uri (GnomeVFSAsyncHandle **handle_return,
 				  GnomeVFSURI *uri,
 				  GnomeVFSOpenMode open_mode,
 				  GnomeVFSAsyncOpenCallback callback,
@@ -212,7 +91,7 @@ pthread_gnome_vfs_async_open_uri (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_open (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_open (GnomeVFSAsyncHandle **handle_return,
 			      const gchar *text_uri,
 			      GnomeVFSOpenMode open_mode,
 			      GnomeVFSAsyncOpenCallback callback,
@@ -257,7 +136,7 @@ async_open_as_channel (GnomeVFSURI *uri,
 }
 
 void
-pthread_gnome_vfs_async_open_uri_as_channel (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_open_uri_as_channel (GnomeVFSAsyncHandle **handle_return,
 					     GnomeVFSURI *uri,
 					     GnomeVFSOpenMode open_mode,
 					     guint advised_block_size,
@@ -273,7 +152,7 @@ pthread_gnome_vfs_async_open_uri_as_channel (GnomeVFSAsyncHandle **handle_return
 }
 
 void
-pthread_gnome_vfs_async_open_as_channel (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_open_as_channel (GnomeVFSAsyncHandle **handle_return,
 					 const gchar *text_uri,
 					 GnomeVFSOpenMode open_mode,
 					 guint advised_block_size,
@@ -321,7 +200,7 @@ async_create (GnomeVFSURI *uri,
 }
 
 void
-pthread_gnome_vfs_async_create_uri (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_create_uri (GnomeVFSAsyncHandle **handle_return,
 				    GnomeVFSURI *uri,
 				    GnomeVFSOpenMode open_mode,
 				    gboolean exclusive,
@@ -338,7 +217,7 @@ pthread_gnome_vfs_async_create_uri (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_create (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_create (GnomeVFSAsyncHandle **handle_return,
 				const gchar *text_uri,
 				GnomeVFSOpenMode open_mode,
 				gboolean exclusive,
@@ -361,7 +240,7 @@ pthread_gnome_vfs_async_create (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_create_as_channel (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_create_as_channel (GnomeVFSAsyncHandle **handle_return,
 					   const gchar *text_uri,
 					   GnomeVFSOpenMode open_mode,
 					   gboolean exclusive,
@@ -391,7 +270,7 @@ pthread_gnome_vfs_async_create_as_channel (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_close (GnomeVFSAsyncHandle *handle,
+gnome_vfs_async_close (GnomeVFSAsyncHandle *handle,
 			       GnomeVFSAsyncCloseCallback callback,
 			       gpointer callback_data)
 {
@@ -430,7 +309,7 @@ pthread_gnome_vfs_async_close (GnomeVFSAsyncHandle *handle,
 }
 
 void
-pthread_gnome_vfs_async_read (GnomeVFSAsyncHandle *handle,
+gnome_vfs_async_read (GnomeVFSAsyncHandle *handle,
 			      gpointer buffer,
 			      guint bytes,
 			      GnomeVFSAsyncReadCallback callback,
@@ -463,7 +342,7 @@ pthread_gnome_vfs_async_read (GnomeVFSAsyncHandle *handle,
 }
 
 void
-pthread_gnome_vfs_async_write (GnomeVFSAsyncHandle *handle,
+gnome_vfs_async_write (GnomeVFSAsyncHandle *handle,
 			       gconstpointer buffer,
 			       guint bytes,
 			       GnomeVFSAsyncWriteCallback callback,
@@ -496,7 +375,7 @@ pthread_gnome_vfs_async_write (GnomeVFSAsyncHandle *handle,
 }
 
 void
-pthread_gnome_vfs_async_create_symbolic_link (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_create_symbolic_link (GnomeVFSAsyncHandle **handle_return,
 					      GnomeVFSURI *uri,
 					      const gchar *uri_reference,
 					      GnomeVFSAsyncOpenCallback callback,
@@ -520,7 +399,7 @@ pthread_gnome_vfs_async_create_symbolic_link (GnomeVFSAsyncHandle **handle_retur
 }
 
 void
-pthread_gnome_vfs_async_get_file_info (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_get_file_info (GnomeVFSAsyncHandle **handle_return,
 				       GList *uris,
 				       GnomeVFSFileInfoOptions options,
 				       GnomeVFSAsyncGetFileInfoCallback callback,
@@ -545,7 +424,7 @@ pthread_gnome_vfs_async_get_file_info (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_set_file_info (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_set_file_info (GnomeVFSAsyncHandle **handle_return,
 				       GnomeVFSURI *uri,
 				       GnomeVFSFileInfo *info,
 				       GnomeVFSSetFileInfoMask mask,
@@ -576,7 +455,7 @@ pthread_gnome_vfs_async_set_file_info (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_find_directory (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_find_directory (GnomeVFSAsyncHandle **handle_return,
 					GList *uris,
 					GnomeVFSFindDirectoryKind kind,
 					gboolean create_if_needed,
@@ -608,9 +487,6 @@ pthread_gnome_vfs_async_find_directory (GnomeVFSAsyncHandle **handle_return,
 static GnomeVFSAsyncHandle *
 async_load_directory (GnomeVFSURI *uri,
 		      GnomeVFSFileInfoOptions options,
-		      GnomeVFSDirectoryFilterType filter_type,
-		      GnomeVFSDirectoryFilterOptions filter_options,
-		      const gchar *filter_pattern,
 		      guint items_per_notification,
 		      GnomeVFSAsyncDirectoryLoadCallback callback,
 		      gpointer callback_data)
@@ -624,9 +500,6 @@ async_load_directory (GnomeVFSURI *uri,
 	load_directory_op = &job->op->specifics.load_directory;
 	load_directory_op->uri = uri == NULL ? NULL : gnome_vfs_uri_ref (uri);
 	load_directory_op->options = options;
-	load_directory_op->filter_type = filter_type;
-	load_directory_op->filter_options = filter_options;
-	load_directory_op->filter_pattern = g_strdup (filter_pattern);
 	load_directory_op->items_per_notification = items_per_notification;
 
 
@@ -637,12 +510,9 @@ async_load_directory (GnomeVFSURI *uri,
 }
 
 void
-pthread_gnome_vfs_async_load_directory (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_load_directory (GnomeVFSAsyncHandle **handle_return,
 					const gchar *text_uri,
 					GnomeVFSFileInfoOptions options,
-					GnomeVFSDirectoryFilterType filter_type,
-					GnomeVFSDirectoryFilterOptions filter_options,
-					const gchar *filter_pattern,
 					guint items_per_notification,
 					GnomeVFSAsyncDirectoryLoadCallback callback,
 					gpointer callback_data)
@@ -655,7 +525,6 @@ pthread_gnome_vfs_async_load_directory (GnomeVFSAsyncHandle **handle_return,
 
 	uri = gnome_vfs_uri_new (text_uri);
 	*handle_return = async_load_directory (uri, options,
-				               filter_type, filter_options, filter_pattern,
 				               items_per_notification,
 				               callback, callback_data);
 	if (uri != NULL) {
@@ -664,12 +533,9 @@ pthread_gnome_vfs_async_load_directory (GnomeVFSAsyncHandle **handle_return,
 }
 
 void
-pthread_gnome_vfs_async_load_directory_uri (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_load_directory_uri (GnomeVFSAsyncHandle **handle_return,
 					    GnomeVFSURI *uri,
 					    GnomeVFSFileInfoOptions options,
-					    GnomeVFSDirectoryFilterType filter_type,
-					    GnomeVFSDirectoryFilterOptions filter_options,
-					    const gchar *filter_pattern,
 					    guint items_per_notification,
 					    GnomeVFSAsyncDirectoryLoadCallback callback,
 					    gpointer callback_data)
@@ -679,13 +545,12 @@ pthread_gnome_vfs_async_load_directory_uri (GnomeVFSAsyncHandle **handle_return,
 	g_return_if_fail (callback != NULL);
 
 	*handle_return = async_load_directory (uri, options,
-					       filter_type, filter_options, filter_pattern,
 					       items_per_notification,
 					       callback, callback_data);
 }
 
 GnomeVFSResult
-pthread_gnome_vfs_async_xfer (GnomeVFSAsyncHandle **handle_return,
+gnome_vfs_async_xfer (GnomeVFSAsyncHandle **handle_return,
 			      GList *source_uri_list,
 			      GList *target_uri_list,
 			      GnomeVFSXferOptions xfer_options,
@@ -723,8 +588,10 @@ pthread_gnome_vfs_async_xfer (GnomeVFSAsyncHandle **handle_return,
 	return GNOME_VFS_OK;
 }
 
+#ifdef OLD_CONTEXT_DEPRECATED
+
 guint
-pthread_gnome_vfs_async_add_status_callback (GnomeVFSAsyncHandle *handle,
+gnome_vfs_async_add_status_callback (GnomeVFSAsyncHandle *handle,
 					     GnomeVFSStatusCallback callback,
 					     gpointer user_data)
 {
@@ -752,7 +619,7 @@ pthread_gnome_vfs_async_add_status_callback (GnomeVFSAsyncHandle *handle,
 }
 
 void
-pthread_gnome_vfs_async_remove_status_callback (GnomeVFSAsyncHandle *handle,
+gnome_vfs_async_remove_status_callback (GnomeVFSAsyncHandle *handle,
 						guint callback_id)
 {
 	GnomeVFSJob *job;
@@ -775,3 +642,5 @@ pthread_gnome_vfs_async_remove_status_callback (GnomeVFSAsyncHandle *handle,
 
 	gnome_vfs_async_job_map_unlock ();
 }
+
+#endif /* OLD_CONTEXT_DEPRECATED */
