@@ -21,17 +21,12 @@
 
    Author: Ettore Perazzoli <ettore@comm2000.it> */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include "gnome-vfs-job-slave.h"
-#include "gnome-vfs-async-job-map.h"
 
-#include "gnome-vfs-private.h"
+#include "gnome-vfs-async-job-map.h"
 #include "gnome-vfs-thread-pool.h"
-#include "gnome-vfs.h"
-#include <gtk/gtk.h>
+#include <glib/gmessages.h>
 #include <pthread.h>
 #include <unistd.h>
 
@@ -147,11 +142,7 @@ gnome_vfs_thread_backend_shutdown (void)
 		/* Some threads are still trying to quit, wait a bit until they
 		 * are done.
 		 */
-#if GNOME_PLATFORM_VERSION >= 1095000
-		g_main_iteration (FALSE);
-#else
-		gtk_main_iteration_do (FALSE);
-#endif
+		g_main_context_iteration (NULL, FALSE);
 		usleep (20000);
 	}
 
