@@ -27,22 +27,22 @@ System (version for POSIX threads).
 
    */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
-#include <glib.h>
 #include "gnome-vfs-job.h"
-#include "gnome-vfs-async-job-map.h"
-#include "gnome-vfs-context.h"
 
+#include "gnome-vfs-async-job-map.h"
+#include "gnome-vfs-job-slave.h"
 #include <errno.h>
 #include <fcntl.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <libgnomevfs/gnome-vfs-cancellable-ops.h>
+#include <libgnomevfs/gnome-vfs-context.h>
+#include <libgnomevfs/gnome-vfs-i18n.h>
+#include <libgnomevfs/gnome-vfs-backend.h>
 #include <string.h>
 #include <unistd.h>
 
-#include "gnome-vfs-job-slave.h"
-
 GStaticPrivate job_private = G_STATIC_PRIVATE_INIT;
 
 #if GNOME_VFS_JOB_DEBUG
@@ -684,7 +684,6 @@ gnome_vfs_op_destroy (GnomeVFSOp *op)
 		if (op->specifics.load_directory.uri != NULL) {
 			gnome_vfs_uri_unref (op->specifics.load_directory.uri);
 		}
-		g_free (op->specifics.load_directory.filter_pattern);
 		break;
 	case GNOME_VFS_OP_OPEN:
 		if (op->specifics.open.uri != NULL) {
@@ -795,7 +794,7 @@ serve_channel_read (GnomeVFSHandle *handle,
 		}
 
 		while (written_bytes_in_buffer < filled_bytes_in_buffer) {
-			guint bytes_written;
+			gsize bytes_written;
 			
 			/* channel_out is nonblocking; if we get
 			   EAGAIN (G_IO_ERROR_AGAIN) then we tried to
@@ -805,10 +804,11 @@ serve_channel_read (GnomeVFSHandle *handle,
 			   collecting data while the main thread is
 			   busy. */
 			
-			io_result = g_io_channel_write (channel_out,
-							(char *) buffer + written_bytes_in_buffer,
-							filled_bytes_in_buffer - written_bytes_in_buffer,
-							&bytes_written);
+			io_result = g_io_channel_write_chars
+				(channel_out,
+				 (char *) buffer + written_bytes_in_buffer,
+				 filled_bytes_in_buffer - written_bytes_in_buffer,
+				 &bytes_written, NULL);
 			
 			if (gnome_vfs_context_check_cancellation(context)) {
 				goto end;
@@ -866,7 +866,7 @@ serve_channel_read (GnomeVFSHandle *handle,
 
  end:
 	g_free (buffer);
-	g_io_channel_close (channel_out);
+	g_io_channel_shutdown (channel_out, TRUE, NULL);
 	g_io_channel_unref (channel_out);
 	g_io_channel_unref (channel_in);
 }
@@ -885,13 +885,13 @@ serve_channel_write (GnomeVFSHandle *handle,
 	while (1) {
 		GnomeVFSResult result;
 		GIOError io_result;
-		guint bytes_read;
-		guint bytes_to_write;
+		gsize bytes_read;
+		gsize bytes_to_write;
 		GnomeVFSFileSize bytes_written;
 		gchar *p;
 
-		io_result = g_io_channel_read (channel_in, buffer, buffer_size,
-					       &bytes_read);
+		io_result = g_io_channel_read_chars (channel_in, buffer, buffer_size,
+						     &bytes_read, NULL);
 		if (io_result == G_IO_ERROR_AGAIN || io_result == G_IO_ERROR_UNKNOWN)
 			/* we will get G_IO_ERROR_UNKNOWN if a signal occurrs */
 			continue;
@@ -920,7 +920,7 @@ serve_channel_write (GnomeVFSHandle *handle,
 	}
 
  end:
-	g_io_channel_close (channel_in);
+	g_io_channel_shutdown (channel_in, TRUE, NULL);
 	g_io_channel_unref (channel_in);
 	g_io_channel_unref (channel_out);
 }
@@ -1367,8 +1367,7 @@ execute_find_directory (GnomeVFSJob *job)
 }
 
 static void
-load_directory_details (GnomeVFSJob *job,
-			GnomeVFSDirectoryFilter *filter)
+load_directory_details (GnomeVFSJob *job)
 {
 	GnomeVFSLoadDirectoryOp *load_directory_op;
 	GnomeVFSDirectoryHandle *handle;
@@ -1388,7 +1387,6 @@ load_directory_details (GnomeVFSJob *job,
 			(&handle,
 			 load_directory_op->uri,
 			 load_directory_op->options,
-			 filter,
 			 job->op->context);
 	}
 
@@ -1462,18 +1460,10 @@ static void
 execute_load_directory (GnomeVFSJob *job)
 {
 	GnomeVFSLoadDirectoryOp *load_directory_op;
-	GnomeVFSDirectoryFilter *filter;
 
 	load_directory_op = &job->op->specifics.load_directory;
 
-	filter = gnome_vfs_directory_filter_new
-		(load_directory_op->filter_type,
-		 load_directory_op->filter_options,
-		 load_directory_op->filter_pattern);
-
-	load_directory_details (job, filter);
-
-	gnome_vfs_directory_filter_destroy (filter);
+	load_directory_details (job);
 }
 
 static gint
@@ -1666,10 +1656,8 @@ clear_current_job (void)
 	gnome_vfs_module_callback_clear_stacks ();
 }
 
-void pthread_gnome_vfs_get_current_context (GnomeVFSContext **context);
-
 void
-pthread_gnome_vfs_get_current_context (GnomeVFSContext **context)
+gnome_vfs_get_current_context (GnomeVFSContext **context)
 {
 	GnomeVFSJob *job;
 	
@@ -1685,20 +1673,12 @@ pthread_gnome_vfs_get_current_context (GnomeVFSContext **context)
 }
 
 void
-pthread_gnome_vfs_dispatch_module_callback (GnomeVFSAsyncModuleCallback callback,
-					    gpointer user_data,
-					    gconstpointer in, size_t in_size,
-					    gpointer out, size_t out_size,
-					    GnomeVFSModuleCallbackResponse response,
-					    gpointer response_data);
-
-void
-pthread_gnome_vfs_dispatch_module_callback (GnomeVFSAsyncModuleCallback callback,
-					    gpointer user_data,
-					    gconstpointer in, size_t in_size,
-					    gpointer out, size_t out_size,
-					    GnomeVFSModuleCallbackResponse response,
-					    gpointer response_data)
+gnome_vfs_dispatch_module_callback (GnomeVFSAsyncModuleCallback callback,
+				    gconstpointer in, size_t in_size,
+				    gpointer out, size_t out_size,
+				    gpointer user_data,
+				    GnomeVFSModuleCallbackResponse response,
+				    gpointer response_data)
 {
 	GnomeVFSJob *job;
 	GnomeVFSNotifyResult notify_result;
