@@ -26,8 +26,9 @@
 #ifndef GNOME_VFS_JOB_PTHREAD_H
 #define GNOME_VFS_JOB_PTHREAD_H
 
-#include "gnome-vfs.h"
-#include "gnome-vfs-private.h"
+#include <libgnomevfs/gnome-vfs-async-ops.h>
+#include <libgnomevfs/gnome-vfs-module-callback.h>
+#include <libgnomevfs/gnome-vfs-module-callback-private.h>
 #include <semaphore.h>
 
 typedef struct GnomeVFSJob GnomeVFSJob;
@@ -224,9 +225,6 @@ typedef struct {
 typedef struct {
 	GnomeVFSURI *uri;
 	GnomeVFSFileInfoOptions options;
-	GnomeVFSDirectoryFilterType filter_type;
-	GnomeVFSDirectoryFilterOptions filter_options;
-	gchar *filter_pattern;
 	guint items_per_notification;
 } GnomeVFSLoadDirectoryOp;
 
