@@ -25,12 +25,15 @@
 #ifndef GNOME_VFS_ASYNC_OPS_H
 #define GNOME_VFS_ASYNC_OPS_H
 
-#include <libgnomevfs/gnome-vfs-directory-filter.h>
+#include <glib/gconvert.h> /* remove when giochannel.h is fixed */
+#include <glib/giochannel.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-find-directory.h>
 #include <libgnomevfs/gnome-vfs-handle.h>
 #include <libgnomevfs/gnome-vfs-xfer.h>
 
+G_BEGIN_DECLS
+
 typedef struct GnomeVFSAsyncHandle GnomeVFSAsyncHandle;
 
 typedef void	(* GnomeVFSAsyncCallback)	(GnomeVFSAsyncHandle *handle,
@@ -193,24 +196,18 @@ void           gnome_vfs_async_set_file_info          (GnomeVFSAsyncHandle
 void           gnome_vfs_async_load_directory         (GnomeVFSAsyncHandle                  **handle_return,
 						       const gchar                           *text_uri,
 						       GnomeVFSFileInfoOptions                options,
-						       GnomeVFSDirectoryFilterType            filter_type,
-						       GnomeVFSDirectoryFilterOptions         filter_options,
-						       const gchar                           *filter_pattern,
 						       guint                                  items_per_notification,
 						       GnomeVFSAsyncDirectoryLoadCallback     callback,
 						       gpointer                               callback_data);
 void           gnome_vfs_async_load_directory_uri     (GnomeVFSAsyncHandle                  **handle_return,
 						       GnomeVFSURI                           *uri,
 						       GnomeVFSFileInfoOptions                options,
-						       GnomeVFSDirectoryFilterType            filter_type,
-						       GnomeVFSDirectoryFilterOptions         filter_options,
-						       const gchar                           *filter_pattern,
 						       guint                                  items_per_notification,
 						       GnomeVFSAsyncDirectoryLoadCallback     callback,
 						       gpointer                               callback_data);
 GnomeVFSResult gnome_vfs_async_xfer                   (GnomeVFSAsyncHandle                  **handle_return,
-						       const GList                           *source_uri_list,
-						       const GList                           *target_uri_list,
+						       GList                                 *source_uri_list,
+						       GList                                 *target_uri_list,
 						       GnomeVFSXferOptions                    xfer_options,
 						       GnomeVFSXferErrorMode                  error_mode,
 						       GnomeVFSXferOverwriteMode              overwrite_mode,
@@ -227,4 +224,6 @@ void           gnome_vfs_async_find_directory         (GnomeVFSAsyncHandle
 						       GnomeVFSAsyncFindDirectoryCallback     callback,
 						       gpointer                               user_data);
 
+G_END_DECLS
+
 #endif /* GNOME_VFS_ASYNC_OPS_H */
