@@ -24,15 +24,21 @@
 #include <config.h>
 #include "gnome-vfs-configuration.h"
 
-#include "gnome-vfs-private.h"
-#include "gnome-vfs.h"
-#include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
-#include <glib.h>
+#include <glib/ghash.h>
+#include <glib/glist.h>
+#include <glib/gmem.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gthread.h>
+#include <glib/gutils.h>
+#include "gnome-vfs-i18n.h"
+#include "gnome-vfs-private.h"
+#include <sys/stat.h>
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 #include <time.h>
 
 typedef struct _Configuration Configuration;
@@ -255,7 +261,7 @@ parse_line (Configuration *configuration,
 		p++;
 	}
 
-	while (*p && isspace ((guchar) *p))
+	while (*p && g_ascii_isspace (*p))
 		p++;
 
 	if (*p == '\0') {
@@ -271,12 +277,12 @@ parse_line (Configuration *configuration,
 	}
 
 	module_name = p;
-	while(*p && !isspace ((guchar) *p)) p++;
+	while(*p && !g_ascii_isspace (*p)) p++;
 
 	if(*p) {
 		*p = '\0';
 		p++;
-		while(*p && isspace ((guchar) *p)) p++;
+		while(*p && g_ascii_isspace (*p)) p++;
 		if(*p)
 			args = p;
 	}
