@@ -21,23 +21,27 @@
    Author: Ettore Perazzoli <ettore@gnu.org>
 */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
+#include "gnome-vfs-init.h"
 
-#include "gnome-vfs.h"
-#include "gnome-vfs-backend.h"
-#include "gnome-vfs-private.h"
+#include "gnome-vfs-ssl-private.h"
 #include "gnome-vfs-mime.h"
 
-#ifdef USING_OAF
-#include <liboaf/liboaf.h>
-#endif
-
+#include "gnome-vfs-configuration.h"
+#include "gnome-vfs-i18n.h"
+#include "gnome-vfs-method.h"
+#include "gnome-vfs-process.h"
+#include "gnome-vfs-utils.h"
+#include <bonobo-activation/bonobo-activation.h>
+#include <glib/gmessages.h>
+#include <libgnomevfs-pthread/gnome-vfs-pthread.h>
+#include <libgnomevfs-pthread/gnome-vfs-job-slave.h>
 
 static gboolean vfs_already_initialized = FALSE;
 G_LOCK_DEFINE_STATIC (vfs_already_initialized);
 
+static GPrivate * private_is_primary_thread;
+
 gboolean 
 gnome_vfs_init (void)
 {
@@ -47,10 +51,12 @@ gnome_vfs_init (void)
 	G_LOCK (vfs_already_initialized);
 
 	if (!vfs_already_initialized) {
-		if (oaf_orb_get() == NULL) {
-			oaf_init (0, bogus_argv);
+		if (bonobo_activation_orb_get() == NULL) {
+			bonobo_activation_init (0, bogus_argv);
 		}
 
+		gnome_vfs_ssl_init ();
+
 		retval = gnome_vfs_method_init ();
 		if (retval) {
 			retval = gnome_vfs_process_init ();
@@ -59,14 +65,18 @@ gnome_vfs_init (void)
 			retval = gnome_vfs_configuration_init ();
 		}
 		if (retval) {
-			gnome_vfs_backend_loadinit(NULL, NULL);
-			retval = gnome_vfs_backend_init (TRUE);
+			retval = gnome_vfs_pthread_init (TRUE);
 		}
 		if (retval) {
 			signal (SIGPIPE, SIG_IGN);
 		}
+
+		if (g_thread_supported()) {
+			private_is_primary_thread = g_private_new (NULL);
+			g_private_set (private_is_primary_thread, GUINT_TO_POINTER (1));
+		}
+		
 	} else {
-		g_warning (_("GNOME VFS already initialized."));
 		retval = TRUE;	/* Who cares after all.  */
 	}
 
@@ -91,32 +101,41 @@ gnome_vfs_initialized (void)
 void
 gnome_vfs_shutdown (void)
 {
-	gnome_vfs_backend_shutdown ();
+	gnome_vfs_thread_backend_shutdown ();
 	gnome_vfs_mime_shutdown ();
 }
 
 void
-gnome_vfs_loadinit(gpointer app, gpointer modinfo)
-{
-	gnome_vfs_backend_loadinit(app, modinfo);
-}
-
-void
-gnome_vfs_preinit(gpointer app, gpointer modinfo)
+gnome_vfs_loadinit (gpointer app, gpointer modinfo)
 {
 }
 
 void
-gnome_vfs_postinit(gpointer app, gpointer modinfo)
+gnome_vfs_preinit (gpointer app, gpointer modinfo)
+{
+}
+
+void
+gnome_vfs_postinit (gpointer app, gpointer modinfo)
 {
 	G_LOCK (vfs_already_initialized);
 
-	gnome_vfs_method_init();
-	gnome_vfs_process_init();
-	gnome_vfs_configuration_init();
-	gnome_vfs_backend_init(FALSE);
-	signal(SIGPIPE, SIG_IGN);
+	gnome_vfs_method_init ();
+	gnome_vfs_process_init ();
+	gnome_vfs_configuration_init ();
+	gnome_vfs_pthread_init (FALSE);
+	signal (SIGPIPE, SIG_IGN);
 
 	vfs_already_initialized = TRUE;
 	G_UNLOCK (vfs_already_initialized);
 }
+
+gboolean
+gnome_vfs_is_primary_thread (void)
+{
+	if (g_thread_supported()) {
+		return GPOINTER_TO_UINT(g_private_get (private_is_primary_thread)) == 1;
+	} else {
+		return TRUE;
+	}
+}
