@@ -29,7 +29,7 @@
 
 #include "gnome-vfs-module-callback-module-api.h"
 #include "gnome-vfs-module-callback-private.h"
-#include "gnome-vfs-backend-private.h"
+#include "gnome-vfs-backend.h"
 
 #include <pthread.h>
 
@@ -151,12 +151,12 @@ async_callback_invoke (gconstpointer in,
 	 */
 	
 	pthread_mutex_lock (&async_callback_mutex);
-	gnome_vfs_backend_dispatch_module_callback (async_callback->callback,
-						    in, in_size,
-						    out, out_size,
-						    async_callback->callback_data, 
-						    async_callback_response,
-						    &response_data);
+	gnome_vfs_dispatch_module_callback (async_callback->callback,
+					    in, in_size,
+					    out, out_size,
+					    async_callback->callback_data, 
+					    async_callback_response,
+					    &response_data);
 	
 	while (!response_data.done) {
 		pthread_cond_wait (&async_callback_cond, &async_callback_mutex);
@@ -866,8 +866,9 @@ gnome_vfs_async_module_callback_pop (const char *callback_name)
  * handler at all is found for @callback_name, the function returns
  * FALSE.
  *
- * Return value: TRUE if a callback was invoked, FALSE if none was set.
- **/
+ * Returns: TRUE if a callback was invoked, FALSE if none was set.
+ *
+ */
 gboolean
 gnome_vfs_module_callback_invoke (const char    *callback_name,
 				  gconstpointer  in,
@@ -967,9 +968,7 @@ gnome_vfs_module_callback_free_stack_info (GnomeVFSModuleCallbackStackInfo *stac
 	clear_callback_table (stack_info->current_callbacks);
 	g_hash_table_destroy (stack_info->current_callbacks); 
 	clear_callback_table (stack_info->current_async_callbacks);
-	g_hash_table_destroy (stack_info->current_async_callbacks);
-	
-	g_free (stack_info);
+	g_hash_table_destroy (stack_info->current_async_callbacks); 
 }
 
 void
