@@ -25,6 +25,8 @@
 #ifndef GNOME_VFS_TYPES_H
 #define GNOME_VFS_TYPES_H
 
+#ifndef GNOME_VFS_DISABLE_DEPRECATED
+
 /* see gnome-vfs-file-size.h for GNOME_VFS_SIZE_IS_<type> */
 /* see gnome-vfs-file-size.h for GNOME_VFS_OFFSET_IS_<type> */
 /* see gnome-vfs-file-size.h for GNOME_VFS_SIZE_FORMAT_STR */
@@ -46,13 +48,6 @@
 /* see gnome-vfs-file-info.h for GnomeVFSFileInfoOptions */
 /* see gnome-vfs-file-info.h for GnomeVFSFileInfoMask */
 /* see gnome-vfs-find-directory.h for GnomeVFSFindDirectoryKind */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryFilterType */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryFilterOptions */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryFilterNeeds */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryVisitOptions */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryFilter */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryFilterFunc */
-/* see gnome-vfs-directory-filter.h for GnomeVFSDirectoryVisitFunc */
 /* see gnome-vfs-xfer.h for GnomeVFSXferOptions */
 /* see gnome-vfs-xfer.h for GnomeVFSXferProgressStatus */
 /* see gnome-vfs-xfer.h for GnomeVFSXferOverwriteMode */
@@ -77,21 +72,17 @@
 /* see gnome-vfs-async-ops.h for GnomeVFSAsyncXferProgressCallback */
 /* see gnome-vfs-async-ops.h for GnomeVFSFindDirectoryResult */
 /* see gnome-vfs-async-ops.h for GnomeVFSAsyncFindDirectoryCallback */
-/* see gnome-vfs-messages.h for GnomeVFSStatusCallback */
 /* see gnome-vfs-module-callback.h for GnomeVFSModuleCallback */
 /* see gnome-vfs-transform.h for GnomeVFSTransformInitFunc */
 /* see gnome-vfs-transform.h for GnomeVFSTransformFunc */
 /* see gnome-vfs-transform.h for GnomeVFSTransform */
-/* see gnome-vfs-messages.h for GnomeVFSMessageCallbacks */
 /* see gnome-vfs-iobuf.h for GnomeVFSIOBuf */
 /* see gnome-vfs-inet-connection.h for GnomeVFSInetConnection */
 
 /* Includes to provide compatibility with programs that
    still include gnome-vfs-types.h directly */
 #include <libgnomevfs/gnome-vfs-async-ops.h>
-#include <libgnomevfs/gnome-vfs-messages.h>
 #include <libgnomevfs/gnome-vfs-module-callback.h>
-#include <libgnomevfs/gnome-vfs-directory-filter.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-file-size.h>
 #include <libgnomevfs/gnome-vfs-find-directory.h>
@@ -102,4 +93,6 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-xfer.h>
 
-#endif /* _GNOME_VFS_TYPES_H */
+#endif /* GNOME_VFS_DISABLE_DEPRECATED */
+
+#endif /* GNOME_VFS_TYPES_H */
