@@ -23,19 +23,19 @@
 
 */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
+#include "gnome-vfs-uri.h"
 
-#include <ctype.h>
+#include "gnome-vfs-private-utils.h"
+#include "gnome-vfs-transform.h"
+#include "gnome-vfs-utils.h"
+#include <glib/ghash.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gstring.h>
 #include <stdio.h>
 #include <string.h>
 
-#include "gnome-vfs.h"
-#include "gnome-vfs-private.h"
-
-/* FIXME bugzilla.eazel.com 2762: The uri->parent field is always NULL; we should get rid of it. */
-
 /* 
    split_toplevel_uri
 
@@ -143,6 +143,7 @@ split_toplevel_uri (const gchar *path, guint path_len,
 	const char *cur;
 	const char *next_delimiter;
 	char *ret;
+	char *host;
 	gboolean success;
 
 	g_assert (host_return != NULL);
@@ -236,7 +237,7 @@ split_toplevel_uri (const gchar *path, guint path_len,
 
 		port = 0;
 
-		for ( ; cur < path_end && '\0' != *cur && isdigit ((guchar) *cur); cur++) {
+		for ( ; cur < path_end && g_ascii_isdigit (*cur); cur++) {
 			port *= 10;
 			port += *cur - '0'; 
 		}
@@ -276,7 +277,9 @@ split_toplevel_uri (const gchar *path, guint path_len,
 
 done:
 	if (*host_return != NULL) {
-		g_strdown (*host_return);
+		host = g_ascii_strdown (*host_return, -1);
+		g_free (*host_return);
+		*host_return = host;
 
 	}
 
@@ -351,16 +354,18 @@ static const gchar *
 get_method_string (const gchar *substring, gchar **method_string)
 {
 	const gchar *p;
+	char *method;
 	
 	for (p = substring;
-	     isalnum ((unsigned char)*p) || *p == '+' || *p == '-' || *p == '.';
+	     g_ascii_isalnum (*p) || *p == '+' || *p == '-' || *p == '.';
 	     p++)
 		;
 
 	if (*p == ':') {
 		/* Found toplevel method specification.  */
-		*method_string = g_strndup (substring, p - substring);
-		g_strdown (*method_string);
+		method = g_strndup (substring, p - substring);
+		*method_string = g_ascii_strdown (method, -1);
+		g_free (method);
 		p++;
 	} else {
 		*method_string = g_strdup ("file");
@@ -550,6 +555,280 @@ destroy_element (GnomeVFSURI *uri)
 	g_free (uri);
 }
 
+static gboolean
+is_uri_relative (const char *uri)
+{
+	const char *current;
+
+	/* RFC 2396 section 3.1 */
+	for (current = uri ; 
+		*current
+		&& 	((*current >= 'a' && *current <= 'z')
+			 || (*current >= 'A' && *current <= 'Z')
+			 || (*current >= '0' && *current <= '9')
+			 || ('-' == *current)
+			 || ('+' == *current)
+			 || ('.' == *current)) ;
+	     current++);
+
+	return  !(':' == *current);
+}
+
+/*
+ * Remove "./" segments
+ * Compact "../" segments inside the URI
+ * Remove "." at the end of the URL 
+ * Leave any ".."'s at the beginning of the URI
+ 
+*/
+/*
+ * FIXME this is not the simplest or most time-efficent way
+ * to do this.  Probably a far more clear way of doing this processing
+ * is to split the path into segments, rather than doing the processing
+ * in place.
+ */
+static void
+remove_internal_relative_components (char *uri_current)
+{
+	char *segment_prev, *segment_cur;
+	gsize len_prev, len_cur;
+
+	len_prev = len_cur = 0;
+	segment_prev = NULL;
+
+	segment_cur = uri_current;
+
+	while (*segment_cur) {
+		len_cur = strcspn (segment_cur, "/");
+
+		if (len_cur == 1 && segment_cur[0] == '.') {
+			/* Remove "." 's */
+			if (segment_cur[1] == '\0') {
+				segment_cur[0] = '\0';
+				break;
+			} else {
+				memmove (segment_cur, segment_cur + 2, strlen (segment_cur + 2) + 1);
+				continue;
+			}
+		} else if (len_cur == 2 && segment_cur[0] == '.' && segment_cur[1] == '.' ) {
+			/* Remove ".."'s (and the component to the left of it) that aren't at the
+			 * beginning or to the right of other ..'s
+			 */
+			if (segment_prev) {
+				if (! (len_prev == 2
+				       && segment_prev[0] == '.'
+				       && segment_prev[1] == '.')) {
+				       	if (segment_cur[2] == '\0') {
+						segment_prev[0] = '\0';
+						break;
+				       	} else {
+						memmove (segment_prev, segment_cur + 3, strlen (segment_cur + 3) + 1);
+
+						segment_cur = segment_prev;
+						len_cur = len_prev;
+
+						/* now we find the previous segment_prev */
+						if (segment_prev == uri_current) {
+							segment_prev = NULL;
+						} else if (segment_prev - uri_current >= 2) {
+							segment_prev -= 2;
+							for ( ; segment_prev > uri_current && segment_prev[0] != '/' 
+							      ; segment_prev-- );
+							if (segment_prev[0] == '/') {
+								segment_prev++;
+							}
+						}
+						continue;
+					}
+				}
+			}
+		}
+
+		/*Forward to next segment */
+
+		if (segment_cur [len_cur] == '\0') {
+			break;
+		}
+		 
+		segment_prev = segment_cur;
+		len_prev = len_cur;
+		segment_cur += len_cur + 1;	
+	}
+	
+}
+
+/* If I had known this relative uri code would have ended up this long, I would
+ * have done it a different way
+ */
+static char *
+make_full_uri_from_relative (const char *base_uri, const char *uri)
+{
+	char *result = NULL;
+
+	g_return_val_if_fail (base_uri != NULL, g_strdup (uri));
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	/* See section 5.2 in RFC 2396 */
+
+	/* FIXME bugzilla.eazel.com 4413: This function does not take
+	 * into account a BASE tag in an HTML document, so its
+	 * functionality differs from what Mozilla itself would do.
+	 */
+
+	if (is_uri_relative (uri)) {
+		char *mutable_base_uri;
+		char *mutable_uri;
+
+		char *uri_current;
+		gsize base_uri_length;
+		char *separator;
+
+		/* We may need one extra character
+		 * to append a "/" to uri's that have no "/"
+		 * (such as help:)
+		 */
+
+		mutable_base_uri = g_malloc(strlen(base_uri)+2);
+		strcpy (mutable_base_uri, base_uri);
+		
+		uri_current = mutable_uri = g_strdup (uri);
+
+		/* Chew off Fragment and Query from the base_url */
+
+		separator = strrchr (mutable_base_uri, '#'); 
+
+		if (separator) {
+			*separator = '\0';
+		}
+
+		separator = strrchr (mutable_base_uri, '?');
+
+		if (separator) {
+			*separator = '\0';
+		}
+
+		if ('/' == uri_current[0] && '/' == uri_current [1]) {
+			/* Relative URI's beginning with the authority
+			 * component inherit only the scheme from their parents
+			 */
+
+			separator = strchr (mutable_base_uri, ':');
+
+			if (separator) {
+				separator[1] = '\0';
+			}			  
+		} else if ('/' == uri_current[0]) {
+			/* Relative URI's beginning with '/' absolute-path based
+			 * at the root of the base uri
+			 */
+
+			separator = strchr (mutable_base_uri, ':');
+
+			/* g_assert (separator), really */
+			if (separator) {
+				/* If we start with //, skip past the authority section */
+				if ('/' == separator[1] && '/' == separator[2]) {
+					separator = strchr (separator + 3, '/');
+					if (separator) {
+						separator[0] = '\0';
+					}
+				} else {
+				/* If there's no //, just assume the scheme is the root */
+					separator[1] = '\0';
+				}
+			}
+		} else if ('#' != uri_current[0]) {
+			/* Handle the ".." convention for relative uri's */
+
+			/* If there's a trailing '/' on base_url, treat base_url
+			 * as a directory path.
+			 * Otherwise, treat it as a file path, and chop off the filename
+			 */
+
+			base_uri_length = strlen (mutable_base_uri);
+			if ('/' == mutable_base_uri[base_uri_length-1]) {
+				/* Trim off '/' for the operation below */
+				mutable_base_uri[base_uri_length-1] = 0;
+			} else {
+				separator = strrchr (mutable_base_uri, '/');
+				if (separator) {
+					*separator = '\0';
+				}
+			}
+
+			remove_internal_relative_components (uri_current);
+
+			/* handle the "../"'s at the beginning of the relative URI */
+			while (0 == strncmp ("../", uri_current, 3)) {
+				uri_current += 3;
+				separator = strrchr (mutable_base_uri, '/');
+				if (separator) {
+					*separator = '\0';
+				} else {
+					/* <shrug> */
+					break;
+				}
+			}
+
+			/* handle a ".." at the end */
+			if (uri_current[0] == '.' && uri_current[1] == '.' 
+			    && uri_current[2] == '\0') {
+
+			    	uri_current += 2;
+				separator = strrchr (mutable_base_uri, '/');
+				if (separator) {
+					*separator = '\0';
+				}
+			}
+
+			/* Re-append the '/' */
+			mutable_base_uri [strlen(mutable_base_uri)+1] = '\0';
+			mutable_base_uri [strlen(mutable_base_uri)] = '/';
+		}
+
+		result = g_strconcat (mutable_base_uri, uri_current, NULL);
+		g_free (mutable_base_uri); 
+		g_free (mutable_uri); 
+
+	} else {
+		result = g_strdup (uri);
+	}
+	
+	return result;
+}
+
+/**
+ * gnome_vfs_uri_resolve_relative
+ * @base: The base URI.
+ * @text_uri: A string representing a possibly relative URI reference
+ * 
+ * Create a new URI from @relative_reference, relative to @base.
+ *
+ * Return value: The new URI.
+ **/
+GnomeVFSURI *
+gnome_vfs_uri_resolve_relative (const GnomeVFSURI *base,
+				const gchar *relative_reference)
+{
+	char *text_base;
+	char *text_new;
+	GnomeVFSURI *uri;
+
+	if (base == NULL) {
+		text_base = g_strdup ("");
+	} else {
+		text_base = gnome_vfs_uri_to_string (base, 0);
+	}
+	text_new = make_full_uri_from_relative (text_base, relative_reference);
+
+	uri = gnome_vfs_uri_new (text_new);
+
+	g_free (text_base);
+	g_free (text_new);
+
+	return uri;
+}
+
 /**
  * gnome_vfs_uri_ref:
  * @uri: A GnomeVFSURI.
@@ -775,7 +1054,7 @@ gnome_vfs_uri_to_string (const GnomeVFSURI *uri,
 	GString *string;
 	gchar *result;
 
-	string = g_string_new(uri->method_string);
+	string = g_string_new (uri->method_string);
 	g_string_append_c (string, ':');
 
 	if (uri->parent == NULL) {
@@ -1236,7 +1515,8 @@ uri_matches_as_parent (const GnomeVFSURI *possible_parent, const GnomeVFSURI *pa
 	GnomeVFSURI *alternate_possible_parent;
 	gboolean result;
 
-	if (strlen (possible_parent->text) == 0) {
+	if (possible_parent->text == NULL ||
+	    strlen (possible_parent->text) == 0) {
 		alternate_possible_parent = gnome_vfs_uri_append_string (possible_parent,
 			GNOME_VFS_URI_PATH_STR);
 
@@ -1575,3 +1855,225 @@ gnome_vfs_uri_list_free (GList *list)
 {
 	g_list_free (gnome_vfs_uri_list_unref (list));
 }
+
+
+static gboolean
+is_uri_partial (const char *uri)
+{
+	const char *current;
+
+	/* RFC 2396 section 3.1 */
+	for (current = uri ; 
+		*current
+		&& 	((*current >= 'a' && *current <= 'z')
+			 || (*current >= 'A' && *current <= 'Z')
+			 || (*current >= '0' && *current <= '9')
+			 || ('-' == *current)
+			 || ('+' == *current)
+			 || ('.' == *current)) ;
+	     current++);
+
+	return  !(':' == *current);
+}
+
+/**
+ * gnome_vfs_uri_make_full_from_relative:
+ * 
+ * Returns a full URI given a full base URI, and a secondary URI which may
+ * be relative.
+ *
+ * Return value: the URI (NULL for some bad errors).
+ **/
+char *
+gnome_vfs_uri_make_full_from_relative (const char *base_uri,
+				       const char *relative_uri)
+{
+	char *result = NULL;
+
+	/* See section 5.2 in RFC 2396 */
+
+	if (base_uri == NULL && relative_uri == NULL) {
+		result = NULL;
+	} else if (base_uri == NULL) {
+		result = g_strdup (relative_uri);
+	} else if (relative_uri == NULL) {
+		result = g_strdup (base_uri);
+	} else if (!is_uri_partial (relative_uri)) {
+		result = g_strdup (relative_uri);
+	} else {
+		char *mutable_base_uri;
+		char *mutable_uri;
+
+		char *uri_current;
+		size_t base_uri_length;
+		char *separator;
+
+		mutable_base_uri = g_strdup (base_uri);
+		uri_current = mutable_uri = g_strdup (relative_uri);
+
+		/* Chew off Fragment and Query from the base_url */
+
+		separator = strrchr (mutable_base_uri, '#'); 
+
+		if (separator) {
+			*separator = '\0';
+		}
+
+		separator = strrchr (mutable_base_uri, '?');
+
+		if (separator) {
+			*separator = '\0';
+		}
+
+		if ('/' == uri_current[0] && '/' == uri_current [1]) {
+			/* Relative URI's beginning with the authority
+			 * component inherit only the scheme from their parents
+			 */
+
+			separator = strchr (mutable_base_uri, ':');
+
+			if (separator) {
+				separator[1] = '\0';
+			}			  
+		} else if ('/' == uri_current[0]) {
+			/* Relative URI's beginning with '/' absolute-path based
+			 * at the root of the base uri
+			 */
+
+			separator = strchr (mutable_base_uri, ':');
+
+			/* g_assert (separator), really */
+			if (separator) {
+				/* If we start with //, skip past the authority section */
+				if ('/' == separator[1] && '/' == separator[2]) {
+					separator = strchr (separator + 3, '/');
+					if (separator) {
+						separator[0] = '\0';
+					}
+				} else {
+				/* If there's no //, just assume the scheme is the root */
+					separator[1] = '\0';
+				}
+			}
+		} else if ('#' != uri_current[0]) {
+			/* Handle the ".." convention for relative uri's */
+
+			/* If there's a trailing '/' on base_url, treat base_url
+			 * as a directory path.
+			 * Otherwise, treat it as a file path, and chop off the filename
+			 */
+
+			base_uri_length = strlen (mutable_base_uri);
+			if ('/' == mutable_base_uri[base_uri_length-1]) {
+				/* Trim off '/' for the operation below */
+				mutable_base_uri[base_uri_length-1] = 0;
+			} else {
+				separator = strrchr (mutable_base_uri, '/');
+				if (separator) {
+					*separator = '\0';
+				}
+			}
+
+			remove_internal_relative_components (uri_current);
+
+			/* handle the "../"'s at the beginning of the relative URI */
+			while (0 == strncmp ("../", uri_current, 3)) {
+				uri_current += 3;
+				separator = strrchr (mutable_base_uri, '/');
+				if (separator) {
+					*separator = '\0';
+				} else {
+					/* <shrug> */
+					break;
+				}
+			}
+
+			/* handle a ".." at the end */
+			if (uri_current[0] == '.' && uri_current[1] == '.' 
+			    && uri_current[2] == '\0') {
+
+			    	uri_current += 2;
+				separator = strrchr (mutable_base_uri, '/');
+				if (separator) {
+					*separator = '\0';
+				}
+			}
+
+			/* Re-append the '/' */
+			mutable_base_uri [strlen(mutable_base_uri)+1] = '\0';
+			mutable_base_uri [strlen(mutable_base_uri)] = '/';
+		}
+
+		result = g_strconcat (mutable_base_uri, uri_current, NULL);
+		g_free (mutable_base_uri); 
+		g_free (mutable_uri); 
+	}
+	
+	return result;
+}
+
+/**
+ * gnome_vfs_uri_list_parse:
+ * @uri_list:
+ * 
+ * Extracts a list of #GnomeVFSURI objects from a standard text/uri-list,
+ * such as one you would get on a drop operation.  Use
+ * #gnome_vfs_uri_list_free when you are done with the list.
+ *
+ * Return value: A GList of GnomeVFSURIs
+ **/
+GList*
+gnome_vfs_uri_list_parse (const gchar* uri_list)
+{
+	/* Note that this is mostly very stolen from old libgnome/gnome-mime.c */
+
+	const gchar *p, *q;
+	gchar *retval;
+	GnomeVFSURI *uri;
+	GList *result = NULL;
+
+	g_return_val_if_fail (uri_list != NULL, NULL);
+
+	p = uri_list;
+
+	/* We don't actually try to validate the URI according to RFC
+	 * 2396, or even check for allowed characters - we just ignore
+	 * comments and trim whitespace off the ends.  We also
+	 * allow LF delimination as well as the specified CRLF.
+	 */
+	while (p != NULL) {
+		if (*p != '#') {
+			while (g_ascii_isspace (*p))
+				p++;
+
+			q = p;
+			while ((*q != '\0')
+			       && (*q != '\n')
+			       && (*q != '\r'))
+				q++;
+
+			if (q > p) {
+				q--;
+				while (q > p
+				       && g_ascii_isspace (*q))
+					q--;
+
+				retval = g_malloc (q - p + 2);
+				strncpy (retval, p, q - p + 1);
+				retval[q - p + 1] = '\0';
+
+				uri = gnome_vfs_uri_new (retval);
+
+				g_free (retval);
+
+				if (uri != NULL)
+					result = g_list_prepend (result, uri);
+			}
+		}
+		p = strchr (p, '\n');
+		if (p != NULL)
+			p++;
+	}
+
+	return g_list_reverse (result);
+}
