@@ -24,7 +24,9 @@
 #ifndef GNOME_VFS_URI_H
 #define GNOME_VFS_URI_H
 
-#include <glib.h>
+#include <glib/glist.h>
+
+G_BEGIN_DECLS
 
 /* This describes a URI element.  */
 typedef struct GnomeVFSURI {
@@ -92,7 +94,7 @@ typedef enum {
 /* FUNCTIONS */
 GnomeVFSURI 	     *gnome_vfs_uri_new                   (const gchar *text_uri);
 GnomeVFSURI 	     *gnome_vfs_uri_resolve_relative      (const GnomeVFSURI *base,
-							   const char *relative_reference);
+							   const gchar *relative_reference);
 GnomeVFSURI 	     *gnome_vfs_uri_ref                   (GnomeVFSURI *uri);
 void        	      gnome_vfs_uri_unref                 (GnomeVFSURI *uri);
 
@@ -101,8 +103,8 @@ GnomeVFSURI          *gnome_vfs_uri_append_string         (const GnomeVFSURI *ur
 GnomeVFSURI          *gnome_vfs_uri_append_path           (const GnomeVFSURI *uri,
 						           const char *path);
 GnomeVFSURI          *gnome_vfs_uri_append_file_name      (const GnomeVFSURI *uri,
-						           const char *filename);
-char       	     *gnome_vfs_uri_to_string             (const GnomeVFSURI *uri,
+						           const gchar *filename);
+gchar       	     *gnome_vfs_uri_to_string             (const GnomeVFSURI *uri,
 						           GnomeVFSURIHideOptions hide_options);
 GnomeVFSURI 	     *gnome_vfs_uri_dup                   (const GnomeVFSURI *uri);
 gboolean    	      gnome_vfs_uri_is_local              (const GnomeVFSURI *uri);
@@ -111,20 +113,20 @@ GnomeVFSURI	     *gnome_vfs_uri_get_parent            (const GnomeVFSURI *uri);
 
 GnomeVFSToplevelURI *gnome_vfs_uri_get_toplevel           (const GnomeVFSURI *uri);
 
-const char 	    *gnome_vfs_uri_get_host_name          (const GnomeVFSURI *uri);
-const char          *gnome_vfs_uri_get_scheme             (const GnomeVFSURI *uri);
+const gchar 	    *gnome_vfs_uri_get_host_name          (const GnomeVFSURI *uri);
+const gchar         *gnome_vfs_uri_get_scheme             (const GnomeVFSURI *uri);
 guint 	    	     gnome_vfs_uri_get_host_port          (const GnomeVFSURI *uri);
-const char 	    *gnome_vfs_uri_get_user_name          (const GnomeVFSURI *uri);
-const char	    *gnome_vfs_uri_get_password           (const GnomeVFSURI *uri);
+const gchar 	    *gnome_vfs_uri_get_user_name          (const GnomeVFSURI *uri);
+const gchar	    *gnome_vfs_uri_get_password           (const GnomeVFSURI *uri);
 
 void		     gnome_vfs_uri_set_host_name          (GnomeVFSURI *uri,
-						           const char *host_name);
+						           const gchar *host_name);
 void 	    	     gnome_vfs_uri_set_host_port          (GnomeVFSURI *uri,
 						           guint host_port);
 void		     gnome_vfs_uri_set_user_name          (GnomeVFSURI *uri,
-						           const char *user_name);
+						           const gchar *user_name);
 void		     gnome_vfs_uri_set_password           (GnomeVFSURI *uri,
-						           const char *password);
+						           const gchar *password);
 
 gboolean	     gnome_vfs_uri_equal	          (const GnomeVFSURI *a,
 						           const GnomeVFSURI *b);
@@ -133,20 +135,26 @@ gboolean	     gnome_vfs_uri_is_parent	          (const GnomeVFSURI *parent,
 						           const GnomeVFSURI *item,
 						           gboolean recursive);
 				  
-const char 	    *gnome_vfs_uri_get_path                (const GnomeVFSURI *uri);
-const char 	    *gnome_vfs_uri_get_basename            (const GnomeVFSURI *uri);
-const char 	    *gnome_vfs_uri_get_fragment_identifier (const GnomeVFSURI *uri);
-char 		    *gnome_vfs_uri_extract_dirname         (const GnomeVFSURI *uri);
-char		    *gnome_vfs_uri_extract_short_name      (const GnomeVFSURI *uri);
-char		    *gnome_vfs_uri_extract_short_path_name (const GnomeVFSURI *uri);
+const gchar 	    *gnome_vfs_uri_get_path                (const GnomeVFSURI *uri);
+const gchar 	    *gnome_vfs_uri_get_basename            (const GnomeVFSURI *uri);
+const gchar 	    *gnome_vfs_uri_get_fragment_identifier (const GnomeVFSURI *uri);
+gchar 		    *gnome_vfs_uri_extract_dirname         (const GnomeVFSURI *uri);
+gchar		    *gnome_vfs_uri_extract_short_name      (const GnomeVFSURI *uri);
+gchar		    *gnome_vfs_uri_extract_short_path_name (const GnomeVFSURI *uri);
 
 gint		     gnome_vfs_uri_hequal 	           (gconstpointer a,
 						            gconstpointer b);
 guint		     gnome_vfs_uri_hash		           (gconstpointer p);
 
+GList               *gnome_vfs_uri_list_parse              (const gchar* uri_list);
 GList               *gnome_vfs_uri_list_ref                (GList *list);
 GList               *gnome_vfs_uri_list_unref              (GList *list);
 GList               *gnome_vfs_uri_list_copy               (GList *list);
 void                 gnome_vfs_uri_list_free               (GList *list);
 
+char                *gnome_vfs_uri_make_full_from_relative (const char *base_uri,
+							    const char *relative_uri);
+
+G_END_DECLS
+
 #endif /* GNOME_VFS_URI_H */
