@@ -22,44 +22,49 @@
    Author: Gene Z. Ragan <gzr@eazel.com> 
 */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
-#include <ctype.h>
+#include "cdda-cddb.h"
 #include <errno.h>
-#include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-#include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gconf/gconf.h>
 #include <libgnomevfs/gnome-vfs-cancellation.h>
 #include <libgnomevfs/gnome-vfs-context.h>
 #include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-module-shared.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <pwd.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
+#include <sys/types.h>
+#include <time.h>
 #include <unistd.h>
 
-
-#define size16 short
-#define size32 int
-
-#include <cdda_interface.h>
 #include <cdda_paranoia.h>
 
-#include "gnome-vfs-module.h"
-#include "gnome-vfs-module-shared.h"
-#include "gnome-vfs-mime.h"
+typedef struct {
+	GnomeVFSURI *uri;
+	GnomeVFSFileInfo *file_info;
+	cdrom_drive *drive;	
+	int access_count;
+	unsigned int cddb_discid;
+	gboolean use_cddb;
+	DiscData disc_data;
+} CDDAContext;
 
-#include "cdda-cddb.h"
-#include "cdda-method.h"
+typedef struct {
+	GnomeVFSURI *uri;
+	gboolean inited;
+	gboolean wrote_header;
+	cdrom_paranoia *paranoia;
+	long cursor;
+	long first_sector, last_sector;
+} ReadHandle;
 
 CDDAContext *global_context = NULL;
 
@@ -81,7 +86,6 @@ static GnomeVFSResult do_open_directory  	(GnomeVFSMethod               	*method
 					  	 GnomeVFSMethodHandle         	**method_handle,
 					  	 GnomeVFSURI                   	*uri,
 					  	 GnomeVFSFileInfoOptions        options,
-					  	 const GnomeVFSDirectoryFilter 	*filter,
 					  	 GnomeVFSContext               	*context);
 static GnomeVFSResult do_close_directory 	(GnomeVFSMethod               	*method,
 					  	 GnomeVFSMethodHandle          	*method_handle,
@@ -275,7 +279,7 @@ do_open (GnomeVFSMethod *method, GnomeVFSMethodHandle **method_handle,
 		
 		dir_uri = gnome_vfs_uri_new (schemedir);
 		options = 0;
-		result = do_open_directory (method, method_handle, dir_uri, options, NULL, NULL);
+		result = do_open_directory (method, method_handle, dir_uri, options, NULL);
 		gnome_vfs_uri_unref (dir_uri);
 
 		if (result != GNOME_VFS_OK) {
@@ -655,7 +659,7 @@ do_get_file_info (GnomeVFSMethod *method,
 static GnomeVFSResult 
 do_open_directory (GnomeVFSMethod *method, GnomeVFSMethodHandle **method_handle,
 		   GnomeVFSURI *uri, GnomeVFSFileInfoOptions options,
-		   const GnomeVFSDirectoryFilter *filter, GnomeVFSContext *context)
+		   GnomeVFSContext *context)
 {
 	cdrom_drive *drive;
 	gboolean use_base, use_cache;
@@ -952,7 +956,7 @@ write_wav_header (gpointer buffer, long bytes)
 		
 		*ptr = "RIFF"; ptr += 4;
 		*ptr = bytes + 44 - 8; ptr += 4;
-		*ptr = "WAVEfmt "); ptr += 8;
+		*ptr = "WAVEfmt "; ptr += 8;
 		*ptr = 16; ptr += 4;
 		*ptr = 1; ptr += 2;
 		*ptr = 2; ptr += 2;
@@ -961,7 +965,7 @@ write_wav_header (gpointer buffer, long bytes)
 		*ptr = 4; ptr += 2;
 		*ptr = 16; ptr += 2;		
 		*ptr = "data"; ptr += 4;
-		*ptr = bytes, 4); ptr += 4;
+		*ptr = bytes; ptr += 4;
 
 		return 44;
 }
@@ -1022,9 +1026,6 @@ vfs_module_init (const char *method_name,
 		gconf_init (1, argv, NULL);
 	}
 
-	gtk_type_init();
-	gtk_signal_init();
-	
 	return &method;
 }
 
