@@ -24,46 +24,52 @@
    	Pavel Cisler <pavel@eazel.com>
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #define _LARGEFILE64_SOURCE
 
-#include <glib.h>
-#if GNOME_PLATFORM_VERSION < 1095000
-#include <libgnome/gnome-defs.h>
-#include <libgnome/gnome-i18n.h>
-#else
-/* FIXME: We need to use gettext, but we can't use the gettext helpers
- * in libgnome since it depends on us, not the other way around.
- * What's the good GNOME 2.0 solution for this?
- */
-#define _(String) (String)
-#define N_(String) (String)
-#endif
+#include <libgnomevfs/gnome-vfs-cancellation.h>
+#include <libgnomevfs/gnome-vfs-context.h>
+#include <libgnomevfs/gnome-vfs-i18n.h>
+#include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-module-shared.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-monitor-private.h>
 #include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gutils.h>
 #include <limits.h>
-#include <malloc.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <stdio.h>
 #include <utime.h>
 #include <string.h>
+#ifdef HAVE_FAM
+#include <fam.h>
+#endif
+#include <gdk/gdk.h>
 
-#include "gnome-vfs-mime.h"
 
-#include "gnome-vfs-cancellation.h"
-#include "gnome-vfs-context.h"
-#include "gnome-vfs-module.h"
-#include "gnome-vfs-method.h"
-#include "gnome-vfs-utils.h"
-#include "gnome-vfs-module-shared.h"
-#include "file-method.h"
+/*#include "file-method.h"*/
 
+#ifdef HAVE_FAM
+FAMConnection *fam_connection = NULL;
+G_LOCK_DEFINE_STATIC (fam_connection);
+
+typedef struct {
+	FAMRequest request;
+	GnomeVFSURI *uri;
+} FileMonitorHandle;
+
+#endif
 
 #ifdef PATH_MAX
 #define	GET_PATH_MAX()	PATH_MAX
@@ -493,15 +499,12 @@ typedef struct {
 
 	gchar *name_buffer;
 	gchar *name_ptr;
-
-	const GnomeVFSDirectoryFilter *filter;
 } DirectoryHandle;
 
 static DirectoryHandle *
 directory_handle_new (GnomeVFSURI *uri,
 		      DIR *dir,
-		      GnomeVFSFileInfoOptions options,
-		      const GnomeVFSDirectoryFilter *filter)
+		      GnomeVFSFileInfoOptions options)
 {
 	DirectoryHandle *result;
 	gchar *full_name;
@@ -530,7 +533,6 @@ directory_handle_new (GnomeVFSURI *uri,
 	g_free (full_name);
 
 	result->options = options;
-	result->filter = filter;
 
 	return result;
 }
@@ -606,8 +608,7 @@ get_stat_info (GnomeVFSFileInfo *file_info,
 	gboolean is_symlink;
 	gboolean recursive;
 	char *link_file_path;
-	char *symlink_name;
-	
+
 	followed_symlink = FALSE;
 	
 	recursive = FALSE;
@@ -644,7 +645,6 @@ get_stat_info (GnomeVFSFileInfo *file_info,
 	gnome_vfs_stat_to_file_info (file_info, statptr);
 
 	if (is_symlink) {
-		symlink_name = NULL;
 		link_file_path = g_strdup (full_name);
 		
 		/* We will either successfully read the link name or return
@@ -658,16 +658,13 @@ get_stat_info (GnomeVFSFileInfo *file_info,
 			 * far as we can.
 			 */
 
-			g_free (symlink_name);
-			symlink_name = read_link (link_file_path);
-			if (symlink_name == NULL) {
+			file_info->symlink_name = read_link (link_file_path);
+			if (file_info->symlink_name == NULL) {
 				g_free (link_file_path);
 				return gnome_vfs_result_from_errno ();
 			}
 			
 			if ((options & GNOME_VFS_FILE_INFO_FOLLOW_LINKS) == 0
-			                /* if we had an earlier ELOOP, don't get in an infinite loop here */
-			        || recursive
 					/* we don't care to follow links */
 				|| lstat (file_info->symlink_name, statptr) != 0
 					/* we can't make out where this points to */
@@ -676,11 +673,9 @@ get_stat_info (GnomeVFSFileInfo *file_info,
 				break;
 			}
 			g_free (link_file_path);
-			link_file_path = g_strdup (symlink_name);
+			link_file_path = g_strdup (file_info->symlink_name);
 		}
 		g_free (link_file_path);
-
-		file_info->symlink_name = symlink_name;
 	}
 
 	return GNOME_VFS_OK;
@@ -714,7 +709,6 @@ do_open_directory (GnomeVFSMethod *method,
 		   GnomeVFSMethodHandle **method_handle,
 		   GnomeVFSURI *uri,
 		   GnomeVFSFileInfoOptions options,
-		   const GnomeVFSDirectoryFilter *filter,
 		   GnomeVFSContext *context)
 {
 	gchar *directory_name;
@@ -731,8 +725,7 @@ do_open_directory (GnomeVFSMethod *method,
 
 	*method_handle
 		= (GnomeVFSMethodHandle *) directory_handle_new (uri, dir,
-								 options,
-								 filter);
+								 options);
 
 	return GNOME_VFS_OK;
 }
@@ -753,31 +746,19 @@ do_close_directory (GnomeVFSMethod *method,
 	return GNOME_VFS_OK;
 }
 
-inline static GnomeVFSResult
-read_directory (DirectoryHandle *handle,
-		GnomeVFSFileInfo *info,
-		gboolean *skip,
-		GnomeVFSContext *context)
+static GnomeVFSResult
+do_read_directory (GnomeVFSMethod *method,
+		   GnomeVFSMethodHandle *method_handle,
+		   GnomeVFSFileInfo *file_info,
+		   GnomeVFSContext *context)
 {
-	const GnomeVFSDirectoryFilter *filter;
-	GnomeVFSDirectoryFilterNeeds filter_needs;
 	struct dirent *result;
 	struct stat statbuf;
 	gchar *full_name;
-	gboolean filter_called;
-
-	/* This makes sure we don't try to filter the file more than
-           once.  */
-	filter_called = FALSE;
-	*skip = FALSE;
-
-	filter = handle->filter;
-	if (filter != NULL) {
-		filter_needs = gnome_vfs_directory_filter_get_needs (filter);
-	} else {
-		filter_needs = GNOME_VFS_DIRECTORY_FILTER_NEEDS_NOTHING;
-	}
+	DirectoryHandle *handle;
 
+	handle = (DirectoryHandle *) method_handle;
+	
 	if (readdir_r (handle->dir, handle->current_entry, &result) != 0) {
 		return gnome_vfs_result_from_errno ();
 	}
@@ -786,26 +767,12 @@ read_directory (DirectoryHandle *handle,
 		return GNOME_VFS_ERROR_EOF;
 	}
 
-	info->name = g_strdup (result->d_name);
-
-	if (filter != NULL
-	    && !filter_called
-	    && (filter_needs
-		  & (GNOME_VFS_DIRECTORY_FILTER_NEEDS_TYPE
-		     | GNOME_VFS_DIRECTORY_FILTER_NEEDS_STAT
-		     | GNOME_VFS_DIRECTORY_FILTER_NEEDS_MIMETYPE)) == 0){
-		if (!gnome_vfs_directory_filter_apply (filter, info)) {
-			*skip = TRUE;
-			return GNOME_VFS_OK;
-		}
-
-		filter_called = TRUE;
-	}
+	file_info->name = g_strdup (result->d_name);
 
 	strcpy (handle->name_ptr, result->d_name);
 	full_name = handle->name_buffer;
 
-	if (get_stat_info (info, full_name, handle->options, &statbuf) != GNOME_VFS_OK) {
+	if (get_stat_info (file_info, full_name, handle->options, &statbuf) != GNOME_VFS_OK) {
 		/* Return OK - this should not terminate the directory iteration
 		 * and we will know from the valid_fields that we don't have the
 		 * stat info.
@@ -813,60 +780,9 @@ read_directory (DirectoryHandle *handle,
 		return GNOME_VFS_OK;
 	}
 	
-	if (filter != NULL && !filter_called
-	    && (filter_needs & GNOME_VFS_DIRECTORY_FILTER_NEEDS_MIMETYPE) == 0) {
-		if (!gnome_vfs_directory_filter_apply (filter, info)) {
-			*skip = TRUE;
-			return GNOME_VFS_OK;
-		}
-		filter_called = TRUE;
-	}
-
-	if (handle->options & GNOME_VFS_FILE_INFO_GET_MIME_TYPE) {
-		get_mime_type (info, full_name, handle->options, &statbuf);
-	}
-
-	if (filter != NULL && !filter_called) {
-		if (!gnome_vfs_directory_filter_apply (filter, info)) {
-			*skip = TRUE;
-			return GNOME_VFS_OK;
-		}
-		filter_called = TRUE;
-	}
-
-	if (filter != NULL && !filter_called) {
-		if (!gnome_vfs_directory_filter_apply (filter, info)) {
-			*skip = TRUE;
-			return GNOME_VFS_OK;
-		}
-		filter_called = TRUE;
-	}
-
 	return GNOME_VFS_OK;
 }
 
-static GnomeVFSResult
-do_read_directory (GnomeVFSMethod *method,
-		   GnomeVFSMethodHandle *method_handle,
-		   GnomeVFSFileInfo *file_info,
-		   GnomeVFSContext *context)
-{
-	GnomeVFSResult result;
-	gboolean skip;
-
-	do {
-		result = read_directory ((DirectoryHandle *) method_handle,
-					 file_info, &skip, context);
-		if (result != GNOME_VFS_OK)
-			break;
-		if (skip)
-			gnome_vfs_file_info_clear (file_info);
-	} while (skip);
-
-	return result;
-}
-
-
 static GnomeVFSResult
 do_get_file_info (GnomeVFSMethod *method,
 		  GnomeVFSURI *uri,
@@ -2063,6 +1979,163 @@ do_set_file_info (GnomeVFSMethod *method,
 	return GNOME_VFS_OK;
 }
 
+#ifdef HAVE_FAM
+static void
+fam_callback (gpointer data, 
+	      gint fd, 
+	      GdkInputCondition condition)
+{
+	FileMonitorHandle *handle;
+	GnomeVFSURI *info_uri = NULL;
+	GnomeVFSMonitorEventType event_type = GNOME_VFS_MONITOR_EVENT_CHANGED;
+
+	G_LOCK (fam_connection);
+
+	while (FAMPending(fam_connection)) {
+		FAMEvent ev;
+		if (FAMNextEvent(fam_connection, &ev) != 1) {
+			gdk_input_remove(fd);
+			FAMClose(fam_connection);
+			g_free(fam_connection);
+			fam_connection = FALSE;
+			G_UNLOCK (fam_connection);
+			return;
+		}
+
+		handle = (FileMonitorHandle *)ev.userdata;
+
+		info_uri = gnome_vfs_uri_append_file_name (handle->uri, 
+				ev.filename);
+
+		switch (ev.code) {
+			case FAMChanged:
+				event_type = GNOME_VFS_MONITOR_EVENT_CHANGED;
+				break;
+			case FAMDeleted:
+				event_type = GNOME_VFS_MONITOR_EVENT_DELETED;
+				break;
+			case FAMStartExecuting:
+				event_type = 
+					GNOME_VFS_MONITOR_EVENT_STARTEXECUTING;
+				break;
+			case FAMStopExecuting:
+				event_type = 
+					GNOME_VFS_MONITOR_EVENT_STOPEXECUTING;
+				break;
+			case FAMCreated:
+				event_type = GNOME_VFS_MONITOR_EVENT_CREATED;
+				break;
+			case FAMAcknowledge:
+			case FAMExists:
+			case FAMEndExist:
+			case FAMMoved:
+				event_type = -1;
+				g_warning ("bad FAM event");
+				break;
+		}
+
+
+		if (event_type != -1) {
+			gnome_vfs_monitor_callback (
+					(GnomeVFSMethodHandle *)handle,
+					info_uri, event_type);
+		}
+	}
+
+	G_UNLOCK (fam_connection);
+}
+
+
+
+static gboolean
+monitor_setup ()
+{
+	G_LOCK (fam_connection);
+
+	if (fam_connection == NULL) {
+		fam_connection = g_malloc0(sizeof(FAMConnection));
+		if (FAMOpen2(fam_connection, "test-monitor") != 0) {
+			g_print ("FAMOpen failed, FAMErrno=%d\n", FAMErrno);
+			g_free(fam_connection);
+			fam_connection = NULL;
+			return FALSE;
+		}
+		gdk_input_add(FAMCONNECTION_GETFD(fam_connection), 
+				GDK_INPUT_READ, fam_callback, fam_connection);
+	}
+
+	G_UNLOCK (fam_connection);
+
+	return TRUE;
+}
+#endif
+
+static GnomeVFSResult
+do_monitor_add (GnomeVFSMethod *method,
+		GnomeVFSMethodHandle **method_handle_return,
+		GnomeVFSURI *uri,
+		GnomeVFSMonitorType monitor_type)
+{
+#ifdef HAVE_FAM
+	FileMonitorHandle *handle;
+	char *filename;
+
+	if (!monitor_setup ()) {
+		return GNOME_VFS_ERROR_NOT_SUPPORTED;
+	}
+
+	handle = g_new0 (FileMonitorHandle, 1);
+	handle->uri = uri;
+	gnome_vfs_uri_ref (uri);
+	filename = get_path_from_uri (uri);
+	
+	if (monitor_type == GNOME_VFS_MONITOR_FILE) {
+		G_LOCK (fam_connection);
+		FAMMonitorFile (fam_connection, filename, 
+			&handle->request, handle);
+		G_UNLOCK (fam_connection);
+	} else {
+		G_LOCK (fam_connection);
+		FAMMonitorDirectory (fam_connection, filename, 
+			&handle->request, handle);
+		G_UNLOCK (fam_connection);
+	}
+
+	*method_handle_return = (GnomeVFSMethodHandle *)handle;
+
+	g_free (filename);
+
+	return GNOME_VFS_OK;
+#else
+	return GNOME_VFS_ERROR_NOT_SUPPORTED;
+#endif
+}
+
+static GnomeVFSResult
+do_monitor_cancel (GnomeVFSMethod *method,
+		   GnomeVFSMethodHandle *method_handle)
+{
+#ifdef HAVE_FAM
+	FileMonitorHandle *handle = (FileMonitorHandle *)method_handle;
+
+	if (!monitor_setup ()) {
+		return GNOME_VFS_ERROR_NOT_SUPPORTED;
+	}
+
+	G_LOCK (fam_connection);
+	FAMCancelMonitor (fam_connection, &handle->request);
+	G_UNLOCK (fam_connection);
+
+	gnome_vfs_uri_unref (handle->uri);
+
+	g_free (handle);
+
+	return GNOME_VFS_OK;
+#else
+	return GNOME_VFS_ERROR_NOT_SUPPORTED;
+#endif
+}
+
 static GnomeVFSMethod method = {
 	sizeof (GnomeVFSMethod),
 	do_open,
@@ -2087,7 +2160,9 @@ static GnomeVFSMethod method = {
 	do_set_file_info,
 	do_truncate,
 	do_find_directory,
-	do_create_symbolic_link
+	do_create_symbolic_link,
+	do_monitor_add,
+	do_monitor_cancel
 };
 
 GnomeVFSMethod *
