@@ -22,24 +22,14 @@
 
 /* FIXME bugzilla.eazel.com 1180: More error checking */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
-#include <gtk/gtk.h>
-#include <string.h>
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
-#include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-
-#include "gnome-vfs-mime.h"
-#include "gnome-vfs-method.h"
-#include "gnome-vfs-module.h"
-
-#include "file-method.h"
+#include <gconf/gconf.h>
+#include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <string.h>
 
 static GnomeVFSResult do_open           (GnomeVFSMethod *method,
 				         GnomeVFSMethodHandle **method_handle,
@@ -72,7 +62,6 @@ static GnomeVFSResult do_open_directory (GnomeVFSMethod *method,
 					 GnomeVFSMethodHandle **method_handle,
 					 GnomeVFSURI *uri,
 					 GnomeVFSFileInfoOptions options,
-					 const GnomeVFSDirectoryFilter *filter,
 					 GnomeVFSContext *context);
 static GnomeVFSResult do_close_directory(GnomeVFSMethod *method,
 					 GnomeVFSMethodHandle *method_handle,
@@ -138,7 +127,6 @@ static GMutex *client_mutex;
 typedef struct {
         GnomeVFSURI *uri;
         GnomeVFSFileInfoOptions options;
-        const GnomeVFSDirectoryFilter *filter;
 
         GSList *subdirs;
         GSList *pairs;
@@ -180,7 +168,6 @@ make_absolute (const char *src)
 static DirectoryHandle *
 directory_handle_new (GnomeVFSURI *uri,
                       GnomeVFSFileInfoOptions options,
-                      const GnomeVFSDirectoryFilter *filter,
                       GSList *subdirs,
                       GSList *pairs)
 {
@@ -190,7 +177,6 @@ directory_handle_new (GnomeVFSURI *uri,
         
         retval->uri = gnome_vfs_uri_ref (uri);
         retval->options = options;
-        retval->filter = filter;
         retval->pairs = pairs;
         retval->subdirs = subdirs;
 #ifdef G_THREADS_ENABLED
@@ -487,7 +473,6 @@ do_open_directory (GnomeVFSMethod *method,
 		   GnomeVFSMethodHandle **method_handle,
                    GnomeVFSURI *uri,
                    GnomeVFSFileInfoOptions options,
-                   const GnomeVFSDirectoryFilter *filter,
 		   GnomeVFSContext *context)
 {
         GSList *pairs;
@@ -539,7 +524,6 @@ do_open_directory (GnomeVFSMethod *method,
         *method_handle = 
 		(GnomeVFSMethodHandle*)directory_handle_new (uri,
 							     options,
-							     filter,
 							     subdirs,
 							     pairs);
 	g_free (dirname);
@@ -597,27 +581,18 @@ file_info_dir (GnomeVFSFileInfo *info,
         return result;
 }
 
-        
+
 static GnomeVFSResult 
-read_directory (DirectoryHandle *handle,
-		GnomeVFSFileInfo *file_info,
-		gboolean *skip)
+do_read_directory (GnomeVFSMethod *method,
+		   GnomeVFSMethodHandle *method_handle,
+                   GnomeVFSFileInfo *file_info,
+		   GnomeVFSContext *context)
 {
-        GnomeVFSResult result;
+	GnomeVFSResult result;
         GSList *tmp;
-	const GnomeVFSDirectoryFilter *filter;
-	GnomeVFSDirectoryFilterNeeds filter_needs;
-	gboolean filter_called;
+	DirectoryHandle *handle;
 
-	filter_called = FALSE;
-        filter = handle->filter;
-
-	if (filter != NULL) {
-		filter_needs = gnome_vfs_directory_filter_get_needs (filter);
-	} else {
-		filter_needs = GNOME_VFS_DIRECTORY_FILTER_NEEDS_NOTHING;
-	}
-	
+	handle = (DirectoryHandle *) method_handle;
 
 	MUTEX_LOCK (handle->mutex);
 	/* Get the next key info */
@@ -642,53 +617,6 @@ read_directory (DirectoryHandle *handle,
 	}
 	MUTEX_UNLOCK (handle->mutex);
 	
-	if (result != GNOME_VFS_OK) {
-		return result;
-	}
-	
-	/* Filter the file */
-	*skip = FALSE;;
-	if (filter != NULL
-	    && !filter_called
-	    && !(filter_needs 
-		 & (GNOME_VFS_DIRECTORY_FILTER_NEEDS_TYPE
-		    | GNOME_VFS_DIRECTORY_FILTER_NEEDS_STAT
-		    | GNOME_VFS_DIRECTORY_FILTER_NEEDS_MIMETYPE))) {
-		if (!gnome_vfs_directory_filter_apply (filter, file_info)) {
-			*skip = TRUE;
-			return GNOME_VFS_OK;
-		}
-		filter_called = TRUE;
-	}
-
-	return result;
-}
-
-static GnomeVFSResult 
-do_read_directory (GnomeVFSMethod *method,
-		   GnomeVFSMethodHandle *method_handle,
-                   GnomeVFSFileInfo *file_info,
-		   GnomeVFSContext *context)
-{
-	GnomeVFSResult result;
-	gboolean skip;
-	
-	skip = FALSE;
-	
-	do {
-		result = read_directory ((DirectoryHandle*)method_handle,
-					 file_info, 
-					 &skip);
-		if (result != GNOME_VFS_OK) {
-			break;
-		}
-		
-		if (skip) {
-			gnome_vfs_file_info_clear (file_info);
-		}
-				
-	} while (skip);
-
 	return result;	    
 }
 
@@ -757,20 +685,7 @@ vfs_module_init (const char *method_name, const char *args)
 		gconf_init (argc, argv, NULL);
 	}
 
-	/* These just return and do nothing if GTK
-	   is already initialized. */
-#if GNOME_PLATFORM_VERSION < 1095000
-	gtk_type_init();
-#else
-	gtk_type_init(G_TYPE_DEBUG_NONE);
-#endif
-
 	client = gconf_client_get_default ();
-
-#if GNOME_PLATFORM_VERSION < 1095000
-	gtk_object_ref(GTK_OBJECT(client));
-	gtk_object_sink(GTK_OBJECT(client));
-#endif
 	
 #ifdef G_THREADS_ENABLED
         if (g_thread_supported ())
@@ -785,12 +700,7 @@ vfs_module_init (const char *method_name, const char *args)
 void
 vfs_module_shutdown (GnomeVFSMethod *method)
 {
-#if GNOME_PLATFORM_VERSION < 1095000
-	gtk_object_destroy(GTK_OBJECT(client));
-	gtk_object_unref(GTK_OBJECT(client));
-#else
 	g_object_unref(G_OBJECT(client));
-#endif
 
 #ifdef G_THREADS_ENABLED
 	if (g_thread_supported ()) {
