@@ -24,17 +24,19 @@
 
 #include <config.h>
 
-#include <glib.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <stdio.h>
 #include <fcntl.h>
-#include <libgnorba/gnorba.h>
+#include <glib/glist.h>
+#include <glib/gmain.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <libgnomevfs/gnome-vfs-async-ops.h>
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <libgnomevfs-pthread/gnome-vfs-job.h>
+#include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 
-#include "gnome-vfs.h"
-#include "gnome-vfs-backend.h"
-
 #define TEST_ASSERT(expression, message) \
 	G_STMT_START { if (!(expression)) test_failed message; } G_STMT_END
 
@@ -108,7 +110,7 @@ wait_for_boolean (gboolean *wait_for_it)
 
 	for (i = 0; i < MAX_THREAD_WAIT; i++) {
 		usleep (1);
-		gtk_main_iteration_do (FALSE);
+		g_main_context_iteration (NULL, FALSE);
 		if (*wait_for_it) {
 			return TRUE;
 		}
@@ -117,18 +119,18 @@ wait_for_boolean (gboolean *wait_for_it)
 }
 
 static gboolean
-wait_until_vfs_threads_gone (void)
+wait_until_vfs_jobs_gone (void)
 {
 	int i;
 
-	if (gnome_vfs_backend_get_job_count () == 0) {
+	if (gnome_vfs_job_get_count () == 0) {
 		return TRUE;
 	}
 
 	for (i = 0; i < MAX_THREAD_WAIT; i++) {
 		usleep (1);
-		gtk_main_iteration_do (FALSE);
-		if (gnome_vfs_backend_get_job_count () == 0) {
+		g_main_context_iteration (NULL, FALSE);
+		if (gnome_vfs_job_get_count () == 0) {
 			return TRUE;
 		}
 	}
@@ -136,17 +138,17 @@ wait_until_vfs_threads_gone (void)
 }
 
 static gboolean
-wait_until_vfs_threads_gone_no_main (void)
+wait_until_vfs_jobs_gone_no_main (void)
 {
 	int i;
 
-	if (gnome_vfs_backend_get_job_count () == 0) {
+	if (gnome_vfs_job_get_count () == 0) {
 		return TRUE;
 	}
 
 	for (i = 0; i < MAX_THREAD_WAIT; i++) {
 		usleep (1);
-		if (gnome_vfs_backend_get_job_count () == 0) {
+		if (gnome_vfs_job_get_count () == 0) {
 			return TRUE;
 		}
 	}
@@ -164,7 +166,7 @@ wait_until_file_descriptors_gone (void)
 
 	for (i = 0; i < MAX_THREAD_WAIT; i++) {
 		usleep (1);
-		gtk_main_iteration_do (FALSE);
+		g_main_context_iteration (NULL, FALSE);
 		if (get_used_file_descriptor_count () == 0) {
 			return TRUE;
 		}
@@ -221,7 +223,7 @@ first_get_file_info (void)
 
 	/* Wait until it is done. */
 	TEST_ASSERT (wait_for_boolean (&test_done), ("first_get_file_info: callback was not called"));
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("first_get_file_info: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("first_get_file_info: job never went away"));
 
 	/* For some reason, this consumes file descriptors.
 	 * I don't know why.
@@ -246,7 +248,7 @@ test_get_file_info (void)
 
 	/* Wait until it is done. */
 	TEST_ASSERT (wait_for_boolean (&test_done), ("get_file_info 1: callback was not called"));
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("get_file_info 1: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("get_file_info 1: job never went away"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("get_file_info 1: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	free_at_start = get_free_file_descriptor_count ();
@@ -265,7 +267,7 @@ test_get_file_info (void)
 	g_free (test_callback_data);
 
 	/* Wait until it is done. */
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("get_file_info 2: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("get_file_info 2: job never went away"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("get_file_info 2: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	TEST_ASSERT (test_done == FALSE, ("get_file_info 2: callback was called"));
@@ -385,7 +387,7 @@ test_open_read_close (void)
 
 	TEST_ASSERT (wait_for_boolean (&file_closed_flag), ("open read close: close callback was not called"));
 
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open read cancel close: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open read cancel close: job never went away"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("open read cancel close: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	free_at_start = get_free_file_descriptor_count ();
@@ -418,7 +420,7 @@ test_open_read_cancel_close (void)
 	TEST_ASSERT (wait_for_boolean (&file_closed_flag), ("open read cancel close: callback was not called"));
 	TEST_ASSERT (!file_read_flag, ("open read cancel close: read callback was called"));
 
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open read cancel close: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open read cancel close: job never went away"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("open read cancel close: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	free_at_start = get_free_file_descriptor_count ();
@@ -443,7 +445,7 @@ test_open_close (void)
 
 	TEST_ASSERT (wait_for_boolean (&file_closed_flag), ("open close: close callback was not called"));
 	
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 1: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 1: job never went away"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("open cancel 1: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	free_at_start = get_free_file_descriptor_count ();
@@ -460,7 +462,7 @@ test_open_cancel (void)
 			      test_callback_data);
 	gnome_vfs_async_cancel (test_handle);
 
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 1: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 1: job never went away"));
 	TEST_ASSERT (!file_open_flag, ("open cancel 1: open callback was called"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("open cancel 1: %d file descriptors leaked", get_used_file_descriptor_count ()));
@@ -472,12 +474,12 @@ test_open_cancel (void)
 			      GNOME_VFS_OPEN_READ,
 			      file_open_callback,
 			      test_callback_data);
-	wait_until_vfs_threads_gone_no_main ();
+	wait_until_vfs_jobs_gone_no_main ();
 	gnome_vfs_async_cancel (test_handle);
 	TEST_ASSERT (wait_until_file_descriptors_gone (),
 		     ("open cancel 2: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	free_at_start = get_free_file_descriptor_count ();
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 2: later thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 2: later job never went away"));
 	TEST_ASSERT (!file_open_flag, ("open cancel 2: open callback was called"));
 }
 
@@ -503,7 +505,7 @@ test_open_fail (void)
 			      file_open_fail_callback,
 			      test_callback_data);
 	TEST_ASSERT (wait_for_boolean (&file_open_flag), ("open fail 1: callback was not called"));
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open fail 1: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open fail 1: job never went away"));
 	TEST_ASSERT (get_used_file_descriptor_count () == 0,
 		     ("open fail 1: %d file descriptors leaked", get_used_file_descriptor_count ()));
 	free_at_start = get_free_file_descriptor_count ();
@@ -514,7 +516,7 @@ my_yield (int count)
 {
 	for (; count > 0; count--) {
 		usleep (100);
-		gtk_main_iteration_do (FALSE);
+		g_main_context_iteration (NULL, FALSE);
 	}
 }
 
@@ -530,9 +532,6 @@ test_load_directory_cancel (int delay_till_cancel, int chunk_count)
 					GNOME_VFS_FILE_INFO_GET_MIME_TYPE
 		 			 | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE
 		 			 | GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
-					GNOME_VFS_DIRECTORY_FILTER_NONE,
-					0,
-					NULL,
 					chunk_count,
 					directory_load_callback,
 					&num_entries);
@@ -541,7 +540,7 @@ test_load_directory_cancel (int delay_till_cancel, int chunk_count)
 	
 	directory_load_flag = FALSE;
 	gnome_vfs_async_cancel (handle);
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 1: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 1: job never went away"));
 	TEST_ASSERT (!directory_load_flag, ("load directory cancel 1: load callback was called"));
 
 	gnome_vfs_async_load_directory (&handle,
@@ -549,9 +548,6 @@ test_load_directory_cancel (int delay_till_cancel, int chunk_count)
 					GNOME_VFS_FILE_INFO_GET_MIME_TYPE
 		 			 | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE
 		 			 | GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
-					GNOME_VFS_DIRECTORY_FILTER_NONE,
-					0,
-					NULL,
 					chunk_count,
 					directory_load_callback,
 					&num_entries);
@@ -560,7 +556,7 @@ test_load_directory_cancel (int delay_till_cancel, int chunk_count)
 	
 	directory_load_flag = FALSE;
 	gnome_vfs_async_cancel (handle);
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 2: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 2: job never went away"));
 	TEST_ASSERT (!directory_load_flag, ("load directory cancel 2: load callback was called"));
 }
 
@@ -576,15 +572,12 @@ test_load_directory_fail (void)
 					GNOME_VFS_FILE_INFO_GET_MIME_TYPE
 		 			 | GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE
 		 			 | GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
-					GNOME_VFS_DIRECTORY_FILTER_NONE,
-					0,
-					NULL,
 					32,
 					directory_load_failed_callback,
 					&num_entries);
 		
 	TEST_ASSERT (wait_for_boolean (&directory_load_failed_flag), ("load directory cancel 1: load callback was not called"));
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 1: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 1: job never went away"));
 }
 
 static gboolean find_directory_flag;
@@ -637,7 +630,7 @@ test_find_directory (int delay_till_cancel)
 	usleep (delay_till_cancel * 100);
 	
 	gnome_vfs_async_cancel (handle);
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 2: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 2: job never went away"));
 	TEST_ASSERT (!find_directory_flag, ("find directory cancel 2: callback was called"));
 
 	
@@ -649,7 +642,7 @@ test_find_directory (int delay_till_cancel)
 	
 	find_directory_flag = FALSE;
 	gnome_vfs_async_cancel (handle);
-	TEST_ASSERT (wait_until_vfs_threads_gone (), ("open cancel 3: thread never went away"));
+	TEST_ASSERT (wait_until_vfs_jobs_gone (), ("open cancel 3: job never went away"));
 	TEST_ASSERT (!find_directory_flag, ("find directory cancel 3: callback was called"));
 
 	gnome_vfs_uri_list_free (vfs_uri_as_list);
@@ -658,22 +651,15 @@ test_find_directory (int delay_till_cancel)
 int
 main (int argc, char **argv)
 {
-	CORBA_Environment ev;
-
 	make_asserts_break("GnomeVFS");
-	/* Initialize the libraries we use. */
-	g_thread_init (NULL);
-	CORBA_exception_init (&ev);
-	gnome_CORBA_init ("test-async-cancel", "0.0", &argc, argv, 0, &ev);
 	gnome_vfs_init ();
 
-	
 	/* Initialize our own stuff. */
 	free_at_start = get_free_file_descriptor_count ();
 
 	/* Do the basic tests of our own tools. */
 	TEST_ASSERT (get_used_file_descriptor_count () == 0, ("file descriptor count"));
-	TEST_ASSERT (gnome_vfs_backend_get_job_count () == 0, ("VFS thread count"));
+	TEST_ASSERT (gnome_vfs_job_get_count () == 0, ("VFS job count"));
 
 	/* Spend those first few file descriptors. */
 	first_get_file_info ();
