@@ -21,21 +21,15 @@
    Author: Ettore Perazzoli <ettore@comm2000.it>
 */
 
-
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
-#include <gnome.h>
-#include <libgnorba/gnorba.h>
+#include <glib/gmain.h>
+#include <libgnomevfs/gnome-vfs-async-ops.h>
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <stdio.h>
 
-#include "gnome-vfs.h"
+static GMainLoop *main_loop;
 
-#ifdef WITH_CORBA
-CORBA_Environment ev;
-#endif
-
-
 /* Callbacks.  */
 static void
 close_callback (GnomeVFSAsyncHandle *handle,
@@ -43,7 +37,7 @@ close_callback (GnomeVFSAsyncHandle *handle,
 		gpointer callback_data)
 {
 	printf ("Close: %s.\n", gnome_vfs_result_to_string (result));
-	gtk_main_quit ();
+	g_main_loop_quit (main_loop);
 }
 
 static void
@@ -67,7 +61,7 @@ read_callback (GnomeVFSAsyncHandle *handle,
 
 	printf ("Now closing the file.\n");
 	gnome_vfs_async_close (handle, close_callback, "close");
-	gtk_main_quit ();
+	g_main_loop_quit (main_loop);
 }
 
 static void
@@ -78,7 +72,7 @@ open_callback  (GnomeVFSAsyncHandle *handle,
 	if (result != GNOME_VFS_OK) {
 		printf ("Open failed: %s.\n",
 			gnome_vfs_result_to_string (result));
-		gtk_main_quit ();
+		g_main_loop_quit (main_loop);
 	} else {
 		gchar *buffer;
 		const gulong buffer_size = 1024;
@@ -95,7 +89,6 @@ open_callback  (GnomeVFSAsyncHandle *handle,
 	}
 }
 
-
 int
 main (int argc, char **argv)
 {
@@ -106,20 +99,6 @@ main (int argc, char **argv)
 		return 1;
 	}
 
-#ifdef WITH_PTHREAD
-	puts ("Initializing threads...");
-	g_thread_init (NULL);
-#endif
-
-#ifdef WITH_CORBA
-	CORBA_exception_init (&ev);
-	puts ("Initializing gnome-libs with CORBA...");
-	gnome_CORBA_init ("test-vfs", "0.0", &argc, argv, 0, &ev);
-#else
-	puts ("Initializing gnome-libs...");
-	gnome_init ("test-vfs", "0.0", argc, argv);
-#endif
-
 	puts ("Initializing gnome-vfs...");
 	gnome_vfs_init ();
 
@@ -129,14 +108,12 @@ main (int argc, char **argv)
 	gnome_vfs_async_open (&handle, argv[1], GNOME_VFS_OPEN_READ,
 			      open_callback, "open_callback");
 
-	puts ("GTK+ main loop running.");
-	gtk_main ();
+	puts ("Main loop running.");
+	main_loop = g_main_loop_new (NULL, TRUE);
+	g_main_loop_run (main_loop);
+	g_main_loop_unref (main_loop);
 
-	puts ("GTK+ main loop finished.");
-
-#ifdef WITH_CORBA
-	CORBA_exception_free (&ev);
-#endif
+	puts ("Main loop finished.");
 
 	puts ("All done");
 
