@@ -21,37 +21,35 @@
 
    Author: Ettore Perazzoli <ettore@comm2000.it> */
 
-
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
-#include <gnome.h>
-#include <libgnorba/gnorba.h>
-
-#include "gnome-vfs.h"
-
-#ifdef WITH_CORBA
-CORBA_Environment ev;
-#endif
+#include <glib/gconvert.h> /* workaround for bug in giochannel.h */
+#include <glib/giochannel.h>
+#include <glib/gmain.h>
+#include <glib/gmessages.h>
+#include <libgnomevfs/gnome-vfs-async-ops.h>
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <stdio.h>
 
 #define BUFFER_SIZE 4096
 
-
-static gboolean io_channel_callback (GIOChannel *source,
-				     GIOCondition condition,
-				     gpointer data)
+static GMainLoop *main_loop;
+
+static gboolean
+io_channel_callback (GIOChannel *source,
+		     GIOCondition condition,
+		     gpointer data)
 {
 	gchar buffer[BUFFER_SIZE + 1];
-	guint bytes_read;
+	gsize bytes_read;
 
 	printf ("\n\n************ IO Channel callback!\n");
 
 	if (condition & G_IO_IN) {
-		g_io_channel_read (source, buffer, sizeof (buffer) - 1, &bytes_read);
+		g_io_channel_read_chars (source, buffer, sizeof (buffer) - 1, &bytes_read, NULL);
 		buffer[bytes_read] = 0;
-		printf ("---> Read %d byte(s):\n%s\n\n(***END***)\n",
-			bytes_read, buffer);
+		printf ("---> Read %lu byte(s):\n%s\n\n(***END***)\n",
+			(gulong)bytes_read, buffer);
 		fflush (stdout);
 	}
 
@@ -63,8 +61,8 @@ static gboolean io_channel_callback (GIOChannel *source,
 	if (condition & G_IO_HUP) {
 		printf ("\n----- EOF -----\n");
 		fflush (stdout);
-		g_io_channel_close (source);
-		gtk_main_quit ();
+		g_io_channel_shutdown (source, FALSE, NULL);
+		g_main_loop_quit (main_loop);
 		return FALSE;
 	}
 
@@ -103,20 +101,6 @@ main (int argc, char **argv)
 		return 1;
 	}
 
-#ifdef WITH_PTHREAD
-	puts ("Initializing threads...");
-	g_thread_init (NULL);
-#endif
-
-#ifdef WITH_CORBA
-	CORBA_exception_init (&ev);
-	puts ("Initializing gnome-libs with CORBA...");
-	gnome_CORBA_init ("test-vfs", "0.0", &argc, argv, 0, &ev);
-#else
-	puts ("Initializing gnome-libs...");
-	gnome_init ("test-vfs", "0.0", argc, argv);
-#endif
-
 	puts ("Initializing gnome-vfs...");
 	gnome_vfs_init ();
 
@@ -128,14 +112,12 @@ main (int argc, char **argv)
 					 "open_callback");
 
 	puts ("GTK+ main loop running.");
-	gtk_main ();
+	main_loop = g_main_loop_new (NULL, TRUE);
+	g_main_loop_run (main_loop);
+	g_main_loop_unref (main_loop);
 
 	puts ("GTK+ main loop finished.");
 
-#ifdef WITH_CORBA
-	CORBA_exception_free (&ev);
-#endif
-
 	puts ("All done");
 
 	while (1)
