@@ -24,22 +24,24 @@
    NB. This code leaks everywhere, don't loose hair.
 */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
+#include <errno.h>
+#include <glib/ghash.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gstring.h>
+#include <glib/gmessages.h>
+#include <glib/gutils.h>
+#include <libgnomevfs/gnome-vfs-init.h>
+#include <libgnomevfs/gnome-vfs-directory.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
+#include <popt.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
 #include <time.h>
-#include <errno.h>
 #include <unistd.h>
 
-#include <gnome.h>
-
-#include "gnome-vfs.h"
-
 #define TEST_DEBUG 0
 
 static char delim[]=" ";
@@ -135,19 +137,18 @@ close_files (void)
 static void
 do_ls (void)
 {
-	GnomeVFSResult         result;
-	GnomeVFSDirectoryList *list;
-	GnomeVFSFileInfo      *info;
+	GnomeVFSResult result;
+	GList *list, *node;
+	GnomeVFSFileInfo *info;
 
 	result = gnome_vfs_directory_list_load (
-		&list, cur_dir, GNOME_VFS_FILE_INFO_DEFAULT,
-		NULL);
+		&list, cur_dir, GNOME_VFS_FILE_INFO_DEFAULT);
 	if (show_if_error (result, "open directory ", cur_dir))
 		return;
 
-	for (info = gnome_vfs_directory_list_first (list);
-	     info; info = gnome_vfs_directory_list_next (list)) {
+	for (node = list; node != NULL; node = node->next) {
 		char prechar = '\0', postchar = '\0';
+		info = node->data;
 
 		if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) {
 			switch (info->type) {
@@ -196,7 +197,7 @@ do_ls (void)
 		printf ("\n");
 	}
 	
-	gnome_vfs_directory_list_destroy (list);
+	gnome_vfs_file_info_list_free (list);
 }
 
 static void
@@ -243,7 +244,7 @@ simple_regexp (const char *regexp, const char *fname)
 		    !(i > 0 && regexp [i - 1] == '\\'))
 			continue;
 
-		if (toupper (regexp [i]) != toupper (fname [j])) {
+		if (g_ascii_tolower (regexp [i]) != g_ascii_tolower (fname [j])) {
 			ret = FALSE;
 			break;
 		}
@@ -267,16 +268,17 @@ simple_regexp (const char *regexp, const char *fname)
 static gboolean
 validate_path (const char *path)
 {
-	GnomeVFSResult         result;
-	GnomeVFSDirectoryList *list;
+	GnomeVFSResult result;
+	GList *list;
 
 	result = gnome_vfs_directory_list_load (
-		&list, path, GNOME_VFS_FILE_INFO_DEFAULT,
-		NULL);
-	if (show_if_error (result, "open directory ", path))
-		return FALSE;
+		&list, path, GNOME_VFS_FILE_INFO_DEFAULT);
 
-	gnome_vfs_directory_list_destroy (list);
+	if (show_if_error (result, "open directory ", path)) {
+		return FALSE;
+	}
+
+	gnome_vfs_file_info_list_free (list);
 
 	return TRUE;
 }
@@ -284,19 +286,19 @@ validate_path (const char *path)
 static char *
 get_regexp_name (const char *regexp, const char *path, gboolean dir)
 {
-	GnomeVFSResult         result;
-	GnomeVFSDirectoryList *list;
-	GnomeVFSFileInfo      *info;
-	char                  *res = NULL;
+	GnomeVFSResult result;
+	GList *list, *node;
+	GnomeVFSFileInfo *info;
+	char *res = NULL;
 
 	result = gnome_vfs_directory_list_load (
-		&list, path, GNOME_VFS_FILE_INFO_DEFAULT,
-		NULL);
+		&list, path, GNOME_VFS_FILE_INFO_DEFAULT);
+
 	if (show_if_error (result, "open directory ", path))
 		return NULL;
 
-	for (info = gnome_vfs_directory_list_first (list);
-	     info; info = gnome_vfs_directory_list_next (list)) {
+	for (node = list; node != NULL; node = node->next) {
+		info = node->data;
 
 		if (simple_regexp (regexp, info->name)) {
 			if (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) {
@@ -312,7 +314,7 @@ get_regexp_name (const char *regexp, const char *path, gboolean dir)
 			}
 		}
 	}
-	gnome_vfs_directory_list_destroy (list);
+	gnome_vfs_file_info_list_free (list);
 
 	return res;
 }
@@ -329,7 +331,7 @@ do_cd (void)
 		return;
 	}
 
-	if (!g_strcasecmp (p, "..")) {
+	if (!g_ascii_strcasecmp (p, "..")) {
 		guint lp;
 		char **tmp;
 		GString *newp = g_string_new ("");
@@ -340,13 +342,13 @@ do_cd (void)
 			return;
 
 		while (tmp [lp + 1]) {
-			g_string_sprintfa (newp, "%s/", tmp [lp]);
+			g_string_printfa (newp, "%s/", tmp [lp]);
 			lp++;
 		}
 		g_free (cur_dir);
 		cur_dir = newp->str;
 		g_string_free (newp, FALSE);
-	} else if (!g_strcasecmp (p, ".")) {
+	} else if (!g_ascii_strcasecmp (p, ".")) {
 	} else {
 		char *newpath;
 
@@ -867,7 +869,7 @@ const struct poptOption options [] = {
 };
 
 int
-main (int argc, char **argv)
+main (int argc, const char **argv)
 {
 	poptContext popt_context;
 	int exit = 0;
@@ -877,11 +879,8 @@ main (int argc, char **argv)
 
 	files = g_hash_table_new (g_str_hash, g_str_equal);
 
-	gnome_init_with_popt_table ("test-vfs", "0.0", argc, argv,
-				    options, 0, &popt_context);
-
-	/* make the stupid "SaveYourself" warning not come up */
-	gnome_client_disconnect (gnome_master_client ());
+	popt_context = poptGetContext ("test-vfs", argc, argv,
+				       options, 0);
 
 	if (interactive)
 		vfserr = stderr;
@@ -929,53 +928,53 @@ main (int argc, char **argv)
 		if (!ptr)
 			continue;
 
-		if (g_strcasecmp (ptr, "ls") == 0)
+		if (g_ascii_strcasecmp (ptr, "ls") == 0)
 			do_ls ();
-		else if (g_strcasecmp (ptr, "cd") == 0)
+		else if (g_ascii_strcasecmp (ptr, "cd") == 0)
 			do_cd ();
-		else if (g_strcasecmp (ptr, "dump") == 0)
+		else if (g_ascii_strcasecmp (ptr, "dump") == 0)
 			do_dump ();
-		else if (g_strcasecmp (ptr, "type") == 0 ||
-			 g_strcasecmp (ptr, "cat") == 0)
+		else if (g_ascii_strcasecmp (ptr, "type") == 0 ||
+			 g_ascii_strcasecmp (ptr, "cat") == 0)
 			do_cat ();
-		else if (g_strcasecmp (ptr, "cp") == 0)
+		else if (g_ascii_strcasecmp (ptr, "cp") == 0)
 			do_cp ();
-		else if (g_strcasecmp (ptr, "rm") == 0)
+		else if (g_ascii_strcasecmp (ptr, "rm") == 0)
 			do_rm ();
-		else if (g_strcasecmp (ptr, "mkdir") == 0)
+		else if (g_ascii_strcasecmp (ptr, "mkdir") == 0)
 			do_mkdir ();
-		else if (g_strcasecmp (ptr, "rmdir") == 0)
+		else if (g_ascii_strcasecmp (ptr, "rmdir") == 0)
 			do_rmdir ();
-		else if (g_strcasecmp (ptr, "mv") == 0)
+		else if (g_ascii_strcasecmp (ptr, "mv") == 0)
 			do_mv ();
-		else if (g_strcasecmp (ptr, "info") == 0 ||
-			 g_strcasecmp (ptr, "stat") == 0)
+		else if (g_ascii_strcasecmp (ptr, "info") == 0 ||
+			 g_ascii_strcasecmp (ptr, "stat") == 0)
 			do_info ();
-		else if (g_strcasecmp (ptr, "findtrash") == 0)
+		else if (g_ascii_strcasecmp (ptr, "findtrash") == 0)
 			do_findtrash ();
-		else if (g_strcasecmp (ptr, "sync") == 0)
+		else if (g_ascii_strcasecmp (ptr, "sync") == 0)
 			fprintf (vfserr, "a shell is like a boat, it lists or syncs (RMS)\n");
-		else if (g_strcasecmp (ptr,"help") == 0 ||
-			 g_strcasecmp (ptr,"?")    == 0 ||
-			 g_strcasecmp (ptr,"info") == 0 ||
-			 g_strcasecmp (ptr,"man")  == 0)
+		else if (g_ascii_strcasecmp (ptr,"help") == 0 ||
+			 g_ascii_strcasecmp (ptr,"?")    == 0 ||
+			 g_ascii_strcasecmp (ptr,"info") == 0 ||
+			 g_ascii_strcasecmp (ptr,"man")  == 0)
 			list_commands ();
-		else if (g_strcasecmp (ptr,"exit") == 0 ||
-			 g_strcasecmp (ptr,"quit") == 0 ||
-			 g_strcasecmp (ptr,"q")    == 0 ||
-			 g_strcasecmp (ptr,"bye") == 0)
+		else if (g_ascii_strcasecmp (ptr,"exit") == 0 ||
+			 g_ascii_strcasecmp (ptr,"quit") == 0 ||
+			 g_ascii_strcasecmp (ptr,"q")    == 0 ||
+			 g_ascii_strcasecmp (ptr,"bye") == 0)
 			exit = 1;
 
 		/* File ops */
-		else if (g_strcasecmp (ptr, "open") == 0)
+		else if (g_ascii_strcasecmp (ptr, "open") == 0)
 			do_open ();
-		else if (g_strcasecmp (ptr, "create") == 0)
+		else if (g_ascii_strcasecmp (ptr, "create") == 0)
 			do_create ();
-		else if (g_strcasecmp (ptr, "close") == 0)
+		else if (g_ascii_strcasecmp (ptr, "close") == 0)
 			do_close ();
-		else if (g_strcasecmp (ptr, "read") == 0)
+		else if (g_ascii_strcasecmp (ptr, "read") == 0)
 			do_read ();
-		else if (g_strcasecmp (ptr, "seek") == 0)
+		else if (g_ascii_strcasecmp (ptr, "seek") == 0)
 			do_seek ();
 		
 		else
